@@ -42,7 +42,7 @@
 // #include "alpha_plane.h"
 #include "surface.h"
 #include "graph.h"
-// #include "graph2.h"
+#include "graph_blend_amap.h"
 
 #include "effectcopy.h"
 #include "ngraph.h"
@@ -68,37 +68,19 @@ static int find_null_surface() {
 	return 0;
 }
 
-static int sf_free_one(int no) {
-	surface_t *s;
-	if (no == 0) return NG;
-	
-	s = suf[no];
-	if (s == NULL) return NG;
-	
-	if (s->pixel) free(s->pixel);
-	if (s->alpha) free(s->alpha);
-	free(s);
-	
+static void sf_free_one(int no) {
+	if (no == 0 || !suf[no]) return;
+	sf_free(suf[no]);
 	suf[no] = NULL;
 	pre_freesurfno = no;
-	return OK;
 }
 
-static int sf_free_all() {
-	int i;
-	surface_t *s;
-	
-	for (i = 1; i < MAX_SURFACE; i++) {
-		if (suf[i] == NULL) continue;
-		s = suf[i];
-		if (s->pixel) free(s->pixel);
-		if (s->alpha) free(s->alpha);
-		free(s);
+static void sf_free_all() {
+	for (int i = 1; i < MAX_SURFACE; i++) {
+		sf_free(suf[i]);
 		suf[i] = NULL;
 	}
-	
 	pre_freesurfno = 1;
-	return OK;
 }
 
 static surface_t *sf_get(int no) {
@@ -136,7 +118,7 @@ static void Init() {
 	// surface0 を pre_freesurfno として返さないように。
 	pre_freesurfno = 1;
 	
-	DEBUG_COMMAND("Gpx.Init %d:", p1);
+	TRACE("Gpx.Init %d:", p1);
 }
 
 static void Gpx_reset(void) {
@@ -151,18 +133,15 @@ static void Create() {
 	           作成に失敗した場合は 0 を返す
 	   width : surface の幅
 	   height: surface の高さ
-	   bpp   : surface の深さ(オリジナルでは24bppのみサポート,
-	                          xsystem35 では display の depth と同じ)
+	   bpp   : surface の深さ(24bppのみサポート)
 	*/
 	int *var   = getCaliVariable();
 	int width  = getCaliValue();
 	int height = getCaliValue();
 	int bpp    = getCaliValue();
-	surface_t *s;
-	
-	//get_surface0();
-	s = sf_create_surface(width, height, sf_get(0)->depth);
-	
+
+	surface_t *s = sf_create_surface(width, height);
+
 	if (s == NULL) {
 		*var = 0;
 	} else {
@@ -171,7 +150,7 @@ static void Create() {
 		suf[no] = s;
 	}
 	
-	DEBUG_COMMAND("Gpx.Create %p,%d,%d,%d:", var, width, height, bpp);
+	TRACE("Gpx.Create %p,%d,%d,%d:", var, width, height, bpp);
 }
 
 static void CreatePixelOnly() {
@@ -187,10 +166,9 @@ static void CreatePixelOnly() {
 	int width  = getCaliValue();
 	int height = getCaliValue();
 	int bpp    = getCaliValue();
-	surface_t *s;
-	
-	s = sf_create_pixel(width, height, sf_get(0)->depth);
-	
+
+	surface_t *s = sf_create_pixel(width, height);
+
 	if (s == NULL) {
 		*var = 0;
 	} else {
@@ -199,7 +177,7 @@ static void CreatePixelOnly() {
 		suf[no] = s;
 	}
 	
-	DEBUG_COMMAND("Gpx.CreatePixelOnly %d,%d,%d,%d:", *var, width, height, bpp);
+	TRACE("Gpx.CreatePixelOnly %d,%d,%d,%d:", *var, width, height, bpp);
 }
 
 static void CreateAMapOnly() {
@@ -225,30 +203,22 @@ static void CreateAMapOnly() {
 		suf[no] = s;
 	}
 	
-	DEBUG_COMMAND("Gpx.CreateAMapOnly %p,%d,%d:", var, width, height);
+	TRACE("Gpx.CreateAMapOnly %p,%d,%d:", var, width, height);
 }
 
 static void IsSurface() {
 	/*
-	  Gpx.IsSurface(): 指定の番号の surface が surface かどうか
-	                   (pixel と alpha の両方のデータを持つ)を調べる
+	  Gpx.IsSurface(): 指定の番号が surface かどうかを調べる
 	  
 	   p1  : surface 番号
 	   var : 結果を返す変数。surface ならば 1, !surface ならば 0
 	*/
 	int p1   = getCaliValue();
 	int *var = getCaliVariable();
-	surface_t *s;
-	
-	s = sf_get(p1);
-	
-	if (s == NULL) {
-		*var = 0;
-	} else {
-		*var = (s->alpha && s->pixel) ? 1 : 0;
-	}
-	
-	DEBUG_COMMAND("Gpx.IsSurface %d,%p:", p1, var);
+
+	*var = sf_get(p1) ? 1 : 0;
+
+	TRACE("Gpx.IsSurface %d,%p:", p1, var);
 }
 
 static void IsPixel() {
@@ -267,10 +237,10 @@ static void IsPixel() {
 	if (s == NULL) {
 		*var = 0;
 	} else {
-		*var = s->pixel ? 1 : 0;
+		*var = s->sdl_surface ? 1 : 0;
 	}
 	
-	DEBUG_COMMAND("Gpx.IsPixel %d,%p:", p1, var);
+	TRACE("Gpx.IsPixel %d,%p:", p1, var);
 }
 
 static void IsAlpha() {
@@ -292,7 +262,7 @@ static void IsAlpha() {
 		*var = s->alpha ? 1 : 0;
 	}
 	
-	DEBUG_COMMAND("Gpx.IsAlpha %d,%p:", p1, var);
+	TRACE("Gpx.IsAlpha %d,%p:", p1, var);
 }
 
 static void GetWidth() {
@@ -314,7 +284,7 @@ static void GetWidth() {
 		*var = s->width;
 	}
 	
-	DEBUG_COMMAND("Gpx.GetWidth %d,%d:", p1, *var);
+	TRACE("Gpx.GetWidth %d,%d:", p1, *var);
 }
 
 static void GetHeight() {
@@ -336,13 +306,13 @@ static void GetHeight() {
 		*var = s->height;
 	}
 	
-	DEBUG_COMMAND("Gpx.GetHeight %d,%d:", p1, *var);
+	TRACE("Gpx.GetHeight %d,%d:", p1, *var);
 }
 
 static void GetCreatedSurface() { /* not used ? */
 	int *var = getCaliVariable();
 	
-	DEBUG_COMMAND_YET("Gpx.GetCreatedSurface %p:", var);
+	TRACE_UNIMPLEMENTED("Gpx.GetCreatedSurface %p:", var);
 }
 
 static void LoadCG() {
@@ -357,21 +327,21 @@ static void LoadCG() {
 	
 	*var = load_cg_main(p1 -1);
 	
-	DEBUG_COMMAND("Gpx.LoadCG %p,%d (%d):", var, p1, *var);
+	TRACE("Gpx.LoadCG %p,%d (%d):", var, p1, *var);
 }
 
 static void GetCGPosX() { /* not useed ? */
 	int *var = getCaliVariable();
 	int p1 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.GetCgPosX %p,%d:", var, p1);
+	TRACE_UNIMPLEMENTED("Gpx.GetCgPosX %p,%d:", var, p1);
 }
 
 static void GetCGPosY() { /* not useed ? */
 	int *var = getCaliVariable();
 	int p1 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.GetCgPosY %p,%d:", var, p1);
+	TRACE_UNIMPLEMENTED("Gpx.GetCgPosY %p,%d:", var, p1);
 }
 
 static void Free() {
@@ -382,7 +352,7 @@ static void Free() {
 	*/
 	int p1 = getCaliValue();
 	
-	DEBUG_COMMAND("Gpx.Free %d:", p1);
+	TRACE("Gpx.Free %d:", p1);
 	
 	if (p1 != 0) {
 		sf_free_one(p1);
@@ -395,7 +365,7 @@ static void FreeAll() {
 	*/
 	sf_free_all();
 	
-	DEBUG_COMMAND("Gpx.FreeAll:");
+	TRACE("Gpx.FreeAll:");
 }
 
 static void Copy() {
@@ -421,25 +391,29 @@ static void Copy() {
 	int sh = getCaliValue();
 	surface_t *src, *dst;
 	
-	DEBUG_COMMAND("Gpx.Copy %d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, ss, sx, sy, sw, sh);
+	TRACE("Gpx.Copy %d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, ss, sx, sy, sw, sh);
 	
 	src = sf_get(ss);
 	dst = sf_get(ds);
 	gr_copy(dst, dx, dy, src, sx, sy, sw, sh);
 }
 
-static void CopyBright() { /* not used ? */
-	int p1 = getCaliValue();
-	int p2 = getCaliValue();
-	int p3 = getCaliValue();
-	int p4 = getCaliValue();
-	int p5 = getCaliValue();
-	int p6 = getCaliValue();
-	int p7 = getCaliValue();
-	int p8 = getCaliValue();
-	int p9 = getCaliValue();
+static void CopyBright(void) {
+	int ds = getCaliValue();
+	int dx = getCaliValue();
+	int dy = getCaliValue();
+	int ss = getCaliValue();
+	int sx = getCaliValue();
+	int sy = getCaliValue();
+	int w = getCaliValue();
+	int h = getCaliValue();
+	int lv = getCaliValue();
 
-	DEBUG_COMMAND_YET("Gpx.CopyBright %d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9);
+	surface_t *dst = sf_get(ds);
+	surface_t *src = sf_get(ss);
+	gr_copy_bright(dst, dx, dy, src, sx, sy, w, h, lv);
+
+	TRACE("Gpx.CopyBright %d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, ss, sx, sy, w, h, lv);
 }
 
 static void CopyAMap() {
@@ -465,25 +439,29 @@ static void CopyAMap() {
 	int sh = getCaliValue();
 	surface_t *src, *dst;
 	
-	DEBUG_COMMAND("Gpx.CopyAMap %d,%d,%d,%d,%d,%d,%d,%d:", da, dx, dy, sa, sx, sy, sw, sh);
+	TRACE("Gpx.CopyAMap %d,%d,%d,%d,%d,%d,%d,%d:", da, dx, dy, sa, sx, sy, sw, sh);
 	
 	src = sf_get(sa);
 	dst = sf_get(da);
 	gr_copy_alpha_map(dst, dx, dy, src, sx, sy, sw, sh);
 }
 
-static void Blend() { /* not used ? */
-	int p1 = getCaliValue();
-	int p2 = getCaliValue();
-	int p3 = getCaliValue();
-	int p4 = getCaliValue();
-	int p5 = getCaliValue();
-	int p6 = getCaliValue();
-	int p7 = getCaliValue();
-	int p8 = getCaliValue();
-	int p9 = getCaliValue();
-	
-	DEBUG_COMMAND_YET("Gpx.Blend %d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9);
+static void Blend(void) {
+	int ds = getCaliValue();
+	int dx = getCaliValue();
+	int dy = getCaliValue();
+	int ss = getCaliValue();
+	int sx = getCaliValue();
+	int sy = getCaliValue();
+	int w = getCaliValue();
+	int h = getCaliValue();
+	int lv = getCaliValue();
+
+	surface_t *dst = sf_get(ds);
+	surface_t *src = sf_get(ss);
+	gr_blend(dst, dx, dy, src, sx, sy, w, h, lv);
+
+	TRACE("Gpx.Blend %d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, ss, sx, sy, w, h, lv);
 }
 
 static void BlendSrcBright() { /* not used ? */
@@ -498,7 +476,7 @@ static void BlendSrcBright() { /* not used ? */
 	int p9 = getCaliValue();
 	int p10 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendSrcBright %d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10);
+	TRACE_UNIMPLEMENTED("Gpx.BlendSrcBright %d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10);
 }
 
 static void BlendAddSatur() { /* not used ? */
@@ -511,7 +489,7 @@ static void BlendAddSatur() { /* not used ? */
 	int p7 = getCaliValue();
 	int p8 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendAddStatur %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
+	TRACE_UNIMPLEMENTED("Gpx.BlendAddStatur %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
 }
 
 static void BlendAMap() {
@@ -537,7 +515,7 @@ static void BlendAMap() {
 	int sh = getCaliValue();
 	surface_t *src, *dst;
 	
-	DEBUG_COMMAND("Gpx.BlendAMap %d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, ss, sx, sy, sw, sh);
+	TRACE("Gpx.BlendAMap %d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, ss, sx, sy, sw, sh);
 	
 	src = sf_get(ss);
 	dst = sf_get(ds);
@@ -554,7 +532,7 @@ static void BlendAMapSrcOnly() { /* not used ? */
 	int p7 = getCaliValue();
 	int p8 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendAMapSrcOnly %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
+	TRACE_UNIMPLEMENTED("Gpx.BlendAMapSrcOnly %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
 }
 
 static void BlendAMapColor() { /* not used ? */
@@ -570,7 +548,7 @@ static void BlendAMapColor() { /* not used ? */
 	int p10 = getCaliValue();
 	int p11 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendAMapColor %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11);
+	TRACE_UNIMPLEMENTED("Gpx.BlendAMapColor %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11);
 }
 
 static void BlendAMapColorAlpha() { /* not used ? */
@@ -587,7 +565,7 @@ static void BlendAMapColorAlpha() { /* not used ? */
 	int p11 = getCaliValue();
 	int p12 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendAMapColorAlpha %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12);
+	TRACE_UNIMPLEMENTED("Gpx.BlendAMapColorAlpha %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12);
 }
 
 static void BlendAMapAlpha() { /* not used ? */
@@ -601,7 +579,7 @@ static void BlendAMapAlpha() { /* not used ? */
 	int p8 = getCaliValue();
 	int p9 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendAMapAlpha %d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9);
+	TRACE_UNIMPLEMENTED("Gpx.BlendAMapAlpha %d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9);
 }
 
 static void BlendAMapBright() { /* not used ? */
@@ -615,7 +593,7 @@ static void BlendAMapBright() { /* not used ? */
 	int p8 = getCaliValue();
 	int p9 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendAMapBright %d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9);
+	TRACE_UNIMPLEMENTED("Gpx.BlendAMapBright %d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9);
 }
 
 static void BlendAMapAlphaSrcBright() { /* not used ? */
@@ -630,7 +608,7 @@ static void BlendAMapAlphaSrcBright() { /* not used ? */
 	int p9 = getCaliValue();
 	int p10 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendAMapBright %d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10);
+	TRACE_UNIMPLEMENTED("Gpx.BlendAMapBright %d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10);
 }
 
 static void BlendUseAMapColor() { /* not used ? */
@@ -647,7 +625,7 @@ static void BlendUseAMapColor() { /* not used ? */
 	int p11 = getCaliValue();
 	int p12 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendUseAMapColor %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12);
+	TRACE_UNIMPLEMENTED("Gpx.BlendUseAMapColor %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12);
 }
 
 static void BlendScreen() { /* not used ? */
@@ -660,7 +638,7 @@ static void BlendScreen() { /* not used ? */
 	int p7 = getCaliValue();
 	int p8 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendScreen %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
+	TRACE_UNIMPLEMENTED("Gpx.BlendScreen %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
 }
 
 static void BlendMultiply() { /* not used ? */
@@ -673,7 +651,7 @@ static void BlendMultiply() { /* not used ? */
 	int p7 = getCaliValue();
 	int p8 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendMultiply %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
+	TRACE_UNIMPLEMENTED("Gpx.BlendMultiply %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
 }
 
 static void BlendScreenAlpha() { /* not used ? */
@@ -687,7 +665,7 @@ static void BlendScreenAlpha() { /* not used ? */
 	int p8 = getCaliValue();
 	int p9 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.BlendScreenAlpha %d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9);
+	TRACE_UNIMPLEMENTED("Gpx.BlendScreenAlpha %d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9);
 }
 
 static void Fill() {
@@ -713,7 +691,7 @@ static void Fill() {
 	int b  = getCaliValue();
 	surface_t *dst;
 	
-	DEBUG_COMMAND("Gpx.Fill %d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, r, g, b);
+	TRACE("Gpx.Fill %d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, r, g, b);
 	
 	dst = sf_get(ds);
 	gr_fill(dst, dx, dy, dw, dh, r, g, b);
@@ -731,21 +709,24 @@ static void FillAlphaColor() { /* not used ? */
 	int lv = getCaliValue();
 	surface_t *dst;
 	
-	DEBUG_COMMAND_YET("Gpx.FillAlphaColor %d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, r, g, b, lv);
+	TRACE("Gpx.FillAlphaColor %d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, r, g, b, lv);
 
 	dst = sf_get(ds);
 	gr_fill_alpha_color(dst, dx, dy, dw, dh, r, g, b, lv);
 }
 
-static void FillAMap() { /* not used ? */
-	int p1 = getCaliValue();
-	int p2 = getCaliValue();
-	int p3 = getCaliValue();
-	int p4 = getCaliValue();
-	int p5 = getCaliValue();
-	int p6 = getCaliValue();
-	
-	DEBUG_COMMAND_YET("Gpx.FillAMap %d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6);
+static void FillAMap(void) {
+	int ds = getCaliValue();
+	int x = getCaliValue();
+	int y = getCaliValue();
+	int w = getCaliValue();
+	int h = getCaliValue();
+	int lv = getCaliValue();
+
+	surface_t *dst = sf_get(ds);
+	gr_fill_alpha_map(dst, x, y, w, h, lv);
+
+	TRACE("Gpx.FillAMap %d,%d,%d,%d,%d,%d:", ds, x, y, w, h, lv);
 }
 
 static void FillAMapOverBorder() {
@@ -770,7 +751,7 @@ static void FillAMapOverBorder() {
 	int d = getCaliValue();
 	surface_t *dst;
 	
-	DEBUG_COMMAND("Gpx.FillAMapOverBorder %d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, s, d);
+	TRACE("Gpx.FillAMapOverBorder %d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, s, d);
 
 	dst = sf_get(ds);
 	gr_fill_alpha_overborder(dst, dx, dy, dw, dh, s, d);
@@ -785,7 +766,7 @@ static void FillAMapUnderBorder() { /* not used ? */
 	int p6 = getCaliValue();
 	int p7 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.FillAMapUnderBorder %d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7);
+	TRACE_UNIMPLEMENTED("Gpx.FillAMapUnderBorder %d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7);
 }
 
 static void SaturDP_DPxSA() { /* not used ? */
@@ -798,7 +779,7 @@ static void SaturDP_DPxSA() { /* not used ? */
 	int p7 = getCaliValue();
 	int p8 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.SaturDP_DPxSA %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
+	TRACE_UNIMPLEMENTED("Gpx.SaturDP_DPxSA %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
 }
 
 static void ScreenDA_DAxSA() { /* not used ? */
@@ -811,7 +792,7 @@ static void ScreenDA_DAxSA() { /* not used ? */
 	int p7 = getCaliValue();
 	int p8 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.ScreenDA_DAxSA %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
+	TRACE_UNIMPLEMENTED("Gpx.ScreenDA_DAxSA %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
 }
 
 static void AddDA_DAxSA() { /* not used ? */
@@ -824,7 +805,7 @@ static void AddDA_DAxSA() { /* not used ? */
 	int p7 = getCaliValue();
 	int p8 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.AddDA_DAxSA %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
+	TRACE_UNIMPLEMENTED("Gpx.AddDA_DAxSA %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
 }
 
 static void SpriteCopyAMap() {
@@ -852,7 +833,7 @@ static void SpriteCopyAMap() {
 	int cl = getCaliValue();
 	surface_t *src, *dst;
 	
-	DEBUG_COMMAND("Gpx.SpriteCopyAMap %d,%d,%d,%d,%d,%d,%d,%d,%d:", da, dx, dy, sa, sx, sy, sw, sh, cl);
+	TRACE("Gpx.SpriteCopyAMap %d,%d,%d,%d,%d,%d,%d,%d,%d:", da, dx, dy, sa, sx, sy, sw, sh, cl);
 	
 	src = sf_get(sa);
 	dst = sf_get(da);
@@ -879,7 +860,7 @@ static void BrightDestOnly() {
 	int r  = getCaliValue();
 	surface_t *dst;
 	
-	DEBUG_COMMAND("Gpx.BrightDestOnly %d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, r);
+	TRACE("Gpx.BrightDestOnly %d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, r);
 	
 	dst = sf_get(ds);
 	
@@ -900,7 +881,7 @@ static void CopyTextureWrap() { /* not used ? */
 	int p11 = getCaliValue();
 	int p12 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.CopyTextureWrap %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12);
+	TRACE_UNIMPLEMENTED("Gpx.CopyTextureWrap %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12);
 }
 
 static void CopyTextureWrapAlpha() { /* not used ? */
@@ -918,7 +899,7 @@ static void CopyTextureWrapAlpha() { /* not used ? */
 	int p12 = getCaliValue();
 	int p13 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.CopyTextureWrapAlpha %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12, p13);
+	TRACE_UNIMPLEMENTED("Gpx.CopyTextureWrapAlpha %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12, p13);
 }
 
 static void CopyStretch() {
@@ -948,7 +929,7 @@ static void CopyStretch() {
 	int sh = getCaliValue();
 	surface_t *src, *dst;
 
-	DEBUG_COMMAND_YET("Gpx.CopyStretch %d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, ss, sx, sy, sw, sh);
+	TRACE("Gpx.CopyStretch %d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, ss, sx, sy, sw, sh);
 	
 	src = sf_get(ss);
 	dst = sf_get(ds);
@@ -968,7 +949,7 @@ static void CopyStretchBlend() { /* not used ? */
 	int p10 = getCaliValue();
 	int p11 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.CopyStretchBlend %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11);
+	TRACE_UNIMPLEMENTED("Gpx.CopyStretchBlend %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11);
 }
 
 static void CopyStretchBlendAMap() {
@@ -998,7 +979,7 @@ static void CopyStretchBlendAMap() {
 	int sh = getCaliValue();
 	surface_t *src, *dst;
 	
-	DEBUG_COMMAND("Gpx.CopyStretchBlendAMap %d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, ss, sx, sy, sw, sh);
+	TRACE("Gpx.CopyStretchBlendAMap %d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, dw, dh, ss, sx, sy, sw, sh);
 
 	src = sf_get(ss);
 	dst = sf_get(ds);
@@ -1015,7 +996,7 @@ static void StretchBlendScreen2x2() { /* not used ? */
 	int p7 = getCaliValue();
 	int p8 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.StretchBlendScreen2x2 %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
+	TRACE_UNIMPLEMENTED("Gpx.StretchBlendScreen2x2 %d,%d,%d,%d,%d,%d,%d,%d:", p1, p2, p3, p4, p5, p6, p7, p8);
 }
 
 
@@ -1049,7 +1030,7 @@ static void StretchBlendScreen2x2WDS() {
 	int sh  = getCaliValue();
 	surface_t *src1, *src2, *dst;
 	
-	DEBUG_COMMAND("Gpx.StretchBlendScreen2x2WDS %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, ss1, sx1, sy1, ss2, sx2, sy2, sw, sh);
+	TRACE("Gpx.StretchBlendScreen2x2WDS %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, ss1, sx1, sy1, ss2, sx2, sy2, sw, sh);
 	
 	src1 = sf_get(ss1);
 	src2 = sf_get(ss2);
@@ -1086,7 +1067,7 @@ static void BlendScreenWDS() {
 	int sh  = getCaliValue();
 	surface_t *src1, *src2, *dst;
 	
-	DEBUG_COMMAND("Gpx.BlendScreenWDS %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, ss1, sx1, sy1, ss2, sx2, sy2, sw, sh);
+	TRACE("Gpx.BlendScreenWDS %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", ds, dx, dy, ss1, sx1, sy1, ss2, sx2, sy2, sw, sh);
 	
 	src1 = sf_get(ss1);
 	src2 = sf_get(ss2);
@@ -1137,25 +1118,11 @@ static void EffectCopy() {
 	int sh   = getCaliValue();
 	int time = getCaliValue();
 	int *var = getCaliVariable();
-	surface_t *dib, *dst, *src;
-	
-	switch(no) {
-	case 1:
-	case 2:
-	case 3:
-	case 4:
-	case 5:
-	case 7:
-	case 11:
-	case 12:
-	case 13:
-		DEBUG_COMMAND("Gpx.EffectCopy %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%p:", no, dx, dy, ss1, sx1, sy1, ss2, sx2, sy2, sw, sh, time, var);
-		break;
-	default:
-		DEBUG_COMMAND_YET("Gpx.EffectCopy %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%p:", no, dx, dy, ss1, sx1, sy1, ss2, sx2, sy2, sw, sh, time, var);
-	}
-	dst = sf_get(ss1);
-	src = sf_get(ss2);
+
+	TRACE("Gpx.EffectCopy %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%p:", no, dx, dy, ss1, sx1, sy1, ss2, sx2, sy2, sw, sh, time, var);
+
+	surface_t *dst = sf_get(ss1);
+	surface_t *src = sf_get(ss2);
 	gpx_effect(no, dx, dy, dst, sx1, sy1, src, sx2, sy2, sw, sh, time, var);
 	
 }
@@ -1163,7 +1130,7 @@ static void EffectCopy() {
 static void SetClickCancelFlag() { /* not used ? */
 	int p1 = getCaliValue();
 	
-	DEBUG_COMMAND_YET("Gpx.SetClikCancelFlag %d:", p1);
+	TRACE_UNIMPLEMENTED("Gpx.SetClikCancelFlag %d:", p1);
 }
 
 static const ModuleFunc functions[] = {
