@@ -7,6 +7,6 @@ void ntmsg_set_place(int type);
 void ntmsg_newline();
 void ntmsg_add(const char *msg);
 int  ntmsg_ana(void);
-void ntmsg_update(sprite_t *sp, MyRectangle *r);
+void ntmsg_update(sprite_t *sp, SDL_Rect *r);
 
 #endif /* __NT_MSG_H__ */
