@@ -10,7 +10,7 @@ struct _ntsnd {
 	int no;
 	int vol;
 	int loop;
-	boolean waitend;
+	bool waitend;
 };
 static struct _ntsnd ntsnd[10];
 
@@ -27,14 +27,14 @@ void nt_cd_play(int no) {
 }
 
 void nt_cd_stop(int msec) {
-	mus_mixer_fadeout_start(MIX_CD, msec, 0, TRUE);
+	mus_mixer_fadeout_start(MIX_CD, msec, 0, true);
 }
 
-void nt_cd_mute(boolean mute) {
+void nt_cd_mute(bool mute) {
 	if (mute) {
-		mus_mixer_fadeout_start(MIX_CD, 0, 0, FALSE);
+		mus_mixer_fadeout_start(MIX_CD, 0, 0, false);
 	} else {
-		mus_mixer_fadeout_start(MIX_CD, 0, 100, FALSE);
+		mus_mixer_fadeout_start(MIX_CD, 0, 100, false);
 	}
 }
 
@@ -56,7 +56,7 @@ void nt_snd_setvol(int ch, int vol) {
 	ntsnd[ch -1].vol = vol;
 }
 
-void nt_snd_waitend(int ch, boolean waitend) {
+void nt_snd_waitend(int ch, bool waitend) {
 	if (ch < 1) return;
 
 	ntsnd[ch -1].waitend = waitend;
@@ -74,13 +74,13 @@ void nt_snd_play(int ch) {
 void nt_snd_stop(int ch, int msec) {
 	if (ch < 1) return;
 	
-	mus_wav_fadeout_start(ch, msec, 0, TRUE);
+	mus_wav_fadeout_start(ch, msec, 0, true);
 }
 
 void nt_snd_stopall(int msec) {
 	int i;
 	
 	for (i = 1; i <= 10; i++) {
-		mus_wav_fadeout_start(i, msec, 0, TRUE);
+		mus_wav_fadeout_start(i, msec, 0, true);
 	}
 }
