@@ -28,7 +28,8 @@
 #include "ags.h"
 #include "input.h"
 #include "sprite.h"
-#include "sdl_core.h"
+#include "gfx.h"
+#include "effect.h"
 
 /*
   効果つき画面更新
@@ -44,25 +45,25 @@ void nt_sp_eupdate(int no, int time, int cancel) {
 
 	nt_sp_update_all(false);
 	
-	enum sdl_effect_type type = from_sact_effect(no - 100);
+	enum effect_type type = from_sact_effect(no - 100);
 	if (type == EFFECT_INVALID) {
 		WARNING("Unimplemented effect %d", no);
 		type = EFFECT_CROSSFADE;
 	}
 	SDL_Rect rect = { 0, 0, main_surface->w, main_surface->h };
-	struct sdl_effect *eff = sdl_effect_init(&rect, NULL, 0, 0, sdl_getDIB(), 0, 0, type);
+	struct effect *eff = effect_init(&rect, NULL, 0, 0, gfx_getDIB(), 0, 0, type);
 
 	int sttime, curtime;
-	sttime = curtime = sdl_getTicks();
+	sttime = curtime = sys_get_ticks();
 	int edtime = curtime + time;
 
-	while ((curtime = sdl_getTicks()) < edtime) {
-		sdl_effect_step(eff, (float)(curtime - sttime) / (edtime - sttime));
-		int rest = 16 - (sdl_getTicks() - curtime);
+	while ((curtime = sys_get_ticks()) < edtime) {
+		effect_step(eff, (float)(curtime - sttime) / (edtime - sttime));
+		int rest = 16 - (sys_get_ticks() - curtime);
 		int key = sys_keywait(rest, cancel ? KEYWAIT_CANCELABLE : KEYWAIT_NONCANCELABLE);
 		if (cancel && key)
 			break;
 	}
-	sdl_effect_finish(eff);
+	effect_finish(eff);
 	ags_updateFull();
 }
