@@ -25,6 +25,7 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <SDL.h>
 #ifdef __EMSCRIPTEN__
 #include <emscripten.h>
 #endif
@@ -46,8 +47,6 @@
 #include "sactsound.h"
 #include "sactcrypto.h"
 #include "sactchart.h"
-#include "ngraph.h"
-#include "surface.h"
 #include "sactamask.h"
 
 /*
@@ -147,23 +146,23 @@ static void Init() {
 	}
 	
 	// create depth map
-	sact.dmap = sf_create_pixel(sf0->width, sf0->height, 16);
+	sact.dmap = SDL_CreateRGBSurface(0, main_surface->w, main_surface->h, 16, 0, 0, 0, 0);
 	
 	// その他 System35 のデフォルト動作の変更
-	ags_setAntialiasedStringMode(TRUE);
+	ags_setAntialiasedStringMode(true);
 	sys_setHankakuMode(2); // 全角半角変換無し
-	ags_autorepeat(FALSE); // key auto repeat off
+	ags_autorepeat(false); // key auto repeat off
 	
 	if (sact.version >= 120) {
-		sact.logging = TRUE;
+		sact.logging = true;
 #ifdef __EMSCRIPTEN__
 		EM_ASM( xsystem35.texthook.disableWheelEvent(0xffffffff) );
 #endif
 	} else {
-		sact.logging = FALSE;
+		sact.logging = false;
 	}
 	
-	DEBUG_COMMAND("SACT.Init %d:", p1);
+	TRACE("SACT.Init %d:", p1);
 }
 
 /**
@@ -184,7 +183,7 @@ static void CreateSprite() {
 	
 	sp_new(wNum, wNumCG1, wNumCG2, wNumCG3, wType);
 	
-	DEBUG_COMMAND_YET("SACT.CreateSprite %d,%d,%d,%d,%d:", wNum, wNumCG1, wNumCG2, wNumCG3, wType);
+	TRACE("SACT.CreateSprite %d,%d,%d,%d,%d:", wNum, wNumCG1, wNumCG2, wNumCG3, wType);
 }
 
 /**
@@ -205,7 +204,7 @@ static void CreateTextSprite() {
 	
 	sp_new_msg(wNum, wX, wY, wWidth, wHeight);
 	
-	DEBUG_COMMAND_YET("SACT.CreateTextSprite %d,%d,%d,%d,%d:", wNum, wX, wY, wWidth, wHeight);
+	TRACE("SACT.CreateTextSprite %d,%d,%d,%d,%d:", wNum, wX, wY, wWidth, wHeight);
 }
 
 /**
@@ -218,7 +217,7 @@ static void SetWallPaper() {
 	
 	sp_set_wall_paper(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.SetWallPaper %d:", wNum);
+	TRACE("SACT.SetWallPaper %d:", wNum);
 }
 
 /**
@@ -228,7 +227,7 @@ static void SetWallPaper() {
 static void Clear() {
 	sp_free_all();
 	
-	DEBUG_COMMAND_YET("SACT.Clear:");
+	TRACE("SACT.Clear:");
 }
 
 /**
@@ -241,7 +240,7 @@ static void Delete() {
 	
 	sp_free(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.Delete %d:", wNum);
+	TRACE("SACT.Delete %d:", wNum);
 }
 
 /**
@@ -259,7 +258,7 @@ static void SpriteDeleteCount() {
 		sp_free(i);
 	}
 	
-	DEBUG_COMMAND_YET("SACT.SpriteDeleteCount %d,%d:", wNum, wCount);
+	TRACE("SACT.SpriteDeleteCount %d,%d:", wNum, wCount);
 }
 
 /**
@@ -267,9 +266,9 @@ static void SpriteDeleteCount() {
  *   現在設定されているスプライト状態を画面に反映(~SP_UPDATE)
  */
 static void Draw() {
-	sp_update_all(TRUE);
+	sp_update_all(true);
 
-	DEBUG_COMMAND_YET("SACT.Draw:");
+	TRACE("SACT.Draw:");
 }
 
 /**
@@ -290,7 +289,7 @@ static void DrawEffect() {
 	
 	sp_eupdate(wType, wEffectTime, wEffectkey);
 	
-	DEBUG_COMMAND_YET("SACT.DrawEffect %d,%d,%d:", wType, wEffectTime, wEffectkey);
+	TRACE("SACT.DrawEffect %d,%d,%d:", wType, wEffectTime, wEffectkey);
 }
 
 /**
@@ -307,7 +306,7 @@ static void DrawEffectAlphaMap() {
 	
 	sp_eupdate_amap(nIndexAlphaMap, wEffectTime, wEffectKey);
 	
-	DEBUG_COMMAND_YET("SACT.DrawEffectAlphaMap %d,%d,%d:", nIndexAlphaMap, wEffectTime, wEffectKey);
+	TRACE("SACT.DrawEffectAlphaMap %d,%d,%d:", nIndexAlphaMap, wEffectTime, wEffectKey);
 }
 
 /**
@@ -334,7 +333,7 @@ static void QuakeScreen() {
 	
 	sp_quake_screen(wType, wParam1, wParam2, wCount, nfKeyEnable);
 	
-	DEBUG_COMMAND_YET("SACT.QuakeScreen %d,%d,%d,%d,%d:", wType, wParam1, wParam2, wCount, nfKeyEnable);
+	TRACE("SACT.QuakeScreen %d,%d,%d,%d,%d:", wType, wParam1, wParam2, wCount, nfKeyEnable);
 }
 
 /**
@@ -350,7 +349,7 @@ static void SetOrigin() {
 	sact.origin.x = wX;
 	sact.origin.y = wY;
 	
-	DEBUG_COMMAND_YET("SACT.SetOrigin %d,%d:", wX, wY);
+	TRACE("SACT.SetOrigin %d,%d:", wX, wY);
 }
 
 /**
@@ -367,7 +366,7 @@ static void SetShow() {
 	
 	sp_set_show(wNum, wCount, wShow);
 
-	DEBUG_COMMAND_YET("SACT.SetShow %d,%d,%d:", wNum, wCount, wShow);
+	TRACE("SACT.SetShow %d,%d,%d:", wNum, wCount, wShow);
 }
 
 /**
@@ -384,7 +383,7 @@ static void SetBlendRate() {
 	
 	sp_set_blendrate(wNum, wCount, nBlendRate);
 	
-	DEBUG_COMMAND_YET("SACT.SetBlendRate %d,%d,%d:", wNum, wCount, nBlendRate);
+	TRACE("SACT.SetBlendRate %d,%d,%d:", wNum, wCount, nBlendRate);
 }
 
 /**
@@ -401,7 +400,7 @@ static void SetPos() {
 	
 	sp_set_pos(wNum, wX, wY);
 	
-	DEBUG_COMMAND_YET("SACT.SetPos %d,%d,%d:", wNum, wX, wY);
+	TRACE("SACT.SetPos %d,%d,%d:", wNum, wX, wY);
 }
 
 /**
@@ -418,7 +417,7 @@ static void SetMove() {
 	
 	sp_set_move(wNum, wX, wY);
 	
-	DEBUG_COMMAND_YET("SACT.SetMove %d,%d,%d:", wNum, wX, wY);
+	TRACE("SACT.SetMove %d,%d,%d:", wNum, wX, wY);
 }
 
 /**
@@ -433,7 +432,7 @@ static void SetMoveTime() {
 	
 	sp_set_movetime(wNum, wTime);
 	
-	DEBUG_COMMAND_YET("SACT.SetMoveTime %d,%d:", wNum, wTime);
+	TRACE("SACT.SetMoveTime %d,%d:", wNum, wTime);
 }
 
 /**
@@ -448,7 +447,7 @@ static void SetMoveSpeed() {
 	
 	sp_set_movespeed(wNum, wSpeed);
 	
-	DEBUG_COMMAND_YET("SACT.SetMoveSpeed %d,%d:", wNum, wSpeed);
+	TRACE("SACT.SetMoveSpeed %d,%d:", wNum, wSpeed);
 }
 
 /**
@@ -468,7 +467,7 @@ static void SetMoveSpeedCount() {
 		sp_set_movespeed(i, wSpeed);
 	}
 	
-	DEBUG_COMMAND_YET("SACT.SetMoveSpeedCount %d,%d,%d:", wNum, wCount, wSpeed);
+	TRACE("SACT.SetMoveSpeedCount %d,%d,%d:", wNum, wCount, wSpeed);
 }
 
 /**
@@ -488,7 +487,7 @@ static void SetSpriteAnimeTimeInterval() {
 		sp_set_animeinterval(i, nTime);
 	}
 	
-	DEBUG_COMMAND_YET("SACT.SetSpriteAnimeTimeInterval %d,%d,%d:", wNum, wCount, nTime);
+	TRACE("SACT.SetSpriteAnimeTimeInterval %d,%d,%d:", wNum, wCount, nTime);
 }
 
 /**
@@ -501,7 +500,7 @@ static void AddZKeyHideSprite() {
 	
 	sp_add_zkey_hidesprite(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.AddZKeyHideSprite %d:", wNum);
+	TRACE("SACT.AddZKeyHideSprite %d:", wNum);
 }
 
 /**
@@ -511,7 +510,7 @@ static void AddZKeyHideSprite() {
 static void ClearZKeyHideSprite() {
 	sp_clear_zkey_hidesprite_all();
 	
-	DEBUG_COMMAND_YET("SACT.ClearZKeyHideSprite:");
+	TRACE("SACT.ClearZKeyHideSprite:");
 }
 
 /**
@@ -527,7 +526,7 @@ static void SpriteFreeze() {
 	
 	sp_freeze_sprite(wNum, wIndex);
 	
-	DEBUG_COMMAND_YET("SACT.SpriteFreeze %d,%d:", wNum, wIndex);
+	TRACE("SACT.SpriteFreeze %d,%d:", wNum, wIndex);
 }
 
 /**
@@ -540,7 +539,7 @@ static void SpriteThaw() {
 	
 	sp_thaw_sprite(wNum);
 
-	DEBUG_COMMAND_YET("SACT.SpriteThaw %d:", wNum);
+	TRACE("SACT.SpriteThaw %d:", wNum);
 }
 
 /**
@@ -560,7 +559,7 @@ static void SpriteFreezeCount() {
 		sp_freeze_sprite(i, wIndex);
 	}
 	
-	DEBUG_COMMAND_YET("SACT.SpriteFreezeCount %d,%d,%d:", wNum, wCount, wIndex);
+	TRACE("SACT.SpriteFreezeCount %d,%d,%d:", wNum, wCount, wIndex);
 }
 
 /**
@@ -578,7 +577,7 @@ static void SpriteThawCount() {
 		sp_thaw_sprite(i);
 	}
 	
-	DEBUG_COMMAND_YET("SACT.SpriteThawCount %d,%d:", wNum, wCount);
+	TRACE("SACT.SpriteThawCount %d,%d:", wNum, wCount);
 }
 
 /**
@@ -591,7 +590,7 @@ static void QuakeSpriteAdd() {
 	
 	sp_add_quakesprite(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.QuakeSpriteAdd %d:", wNum);
+	TRACE("SACT.QuakeSpriteAdd %d:", wNum);
 }
 
 /**
@@ -600,7 +599,7 @@ static void QuakeSpriteAdd() {
  */
 static void QuakeSpriteReset() {
 	sp_clear_quakesprite_all();
-	DEBUG_COMMAND_YET("SACT.QuakeSpriteReset:");
+	TRACE("SACT.QuakeSpriteReset:");
 }
 
 /**
@@ -626,7 +625,7 @@ static void QuakeSprite() {
 	
 	sp_quake_sprite(wType, wAmplitudeX, wAmplitudeY, wCount, nfKeyEnable);
 	
-	DEBUG_COMMAND_YET("SACT.QuakeSprite %d,%d,%d,%d:", wType, wAmplitudeX, wAmplitudeY, wCount);
+	TRACE("SACT.QuakeSprite %d,%d,%d,%d:", wType, wAmplitudeX, wAmplitudeY, wCount);
 }
 
 /**
@@ -639,9 +638,9 @@ static void QuerySpriteIsExist() {
 	int wNum = getCaliValue();
 	int *var = getCaliVariable();
 
-	sp_query_isexist(wNum, var);
+	*var = sp_exists(wNum) ? 1 : 0;
 	
-	DEBUG_COMMAND_YET("SACT.QuerySpriteIsExist %d,%p:", wNum, var);
+	TRACE("SACT.QuerySpriteIsExist %d,%p:", wNum, var);
 }
 
 /**
@@ -662,7 +661,7 @@ static void QuerySpriteInfo() {
 	
 	sp_query_info(wNum, vType, vCG1, vCG2, vCG3);
 	
-	DEBUG_COMMAND_YET("SACT.QuerySpriteInfo %d,%p,%p,%p,%p:", wNum, vType, vCG1, vCG2, vCG3);
+	TRACE("SACT.QuerySpriteInfo %d,%p,%p,%p,%p:", wNum, vType, vCG1, vCG2, vCG3);
 }
 
 /**
@@ -677,7 +676,7 @@ static void QuerySpriteShow() {
 
 	sp_query_show(wNum, vShow);
 	
-	DEBUG_COMMAND_YET("SACT.QuerySpriteShow %d,%p:", wNum, vShow);
+	TRACE("SACT.QuerySpriteShow %d,%p:", wNum, vShow);
 }
 
 /**
@@ -694,7 +693,7 @@ static void QuerySpritePos() {
 	
 	sp_query_pos(wNum, vX, vY);
 	
-	DEBUG_COMMAND_YET("SACT.QuerySpritePos %d,%p,%p:", wNum, vX, vY);
+	TRACE("SACT.QuerySpritePos %d,%p,%p:", wNum, vX, vY);
 }
 
 /**
@@ -711,7 +710,7 @@ static void QuerySpriteSize() {
 	
 	sp_query_size(wNum, vWidth, vHeight);
 	
-	DEBUG_COMMAND_YET("SACT.QuerySpriteSize %d,%p,%p:", wNum, vWidth, vHeight);
+	TRACE("SACT.QuerySpriteSize %d,%p,%p:", wNum, vWidth, vHeight);
 }
 
 /**
@@ -728,7 +727,7 @@ static void QueryTextPos() {
 	
 	sp_query_textpos(wNum, vX, vY);
 	
-	DEBUG_COMMAND_YET("SACT.QueryTextPos %d,%p,%p:", wNum, vX, vY);
+	TRACE("SACT.QueryTextPos %d,%p,%p:", wNum, vX, vY);
 }
 
 /**
@@ -738,7 +737,7 @@ static void QueryTextPos() {
 static void CG_Clear() {
 	scg_freeall();
 	
-	DEBUG_COMMAND_YET("SACT.CG_Clear:");
+	TRACE("SACT.CG_Clear:");
 }
 
 /**
@@ -751,7 +750,7 @@ static void CG_Reset() {
 	
 	scg_free(wNumCG);
 	
-	DEBUG_COMMAND_YET("SACT.CG_Reset %d:", wNumCG);
+	TRACE("SACT.CG_Reset %d:", wNumCG);
 }
 
 /**
@@ -765,9 +764,9 @@ static void CG_QueryType() {
 	int wNumCG = getCaliValue();
 	int *vType = getCaliVariable();
 	
-	scg_querytype(wNumCG, vType);
+	*vType = scg_querytype(wNumCG);
 	
-	DEBUG_COMMAND_YET("SACT.CG_QueryType %d,%p:", wNumCG, vType);
+	TRACE("SACT.CG_QueryType %d,%p:", wNumCG, vType);
 }
 
 /**
@@ -784,7 +783,7 @@ static void CG_QuerySize() {
 	
 	scg_querysize(wNumCG, vWidth, vHeight);
 	
-	DEBUG_COMMAND_YET("SACT.CG_QuerySize %d,%p,%p:", wNumCG, vWidth, vHeight);
+	TRACE("SACT.CG_QuerySize %d,%p,%p:", wNumCG, vWidth, vHeight);
 }
 
 /**
@@ -797,9 +796,9 @@ static void CG_QueryBpp() {
 	int wNumCG = getCaliValue();
 	int *vBpp  = getCaliVariable();
 	
-	scg_querybpp(wNumCG, vBpp);
+	*vBpp = scg_querybpp(wNumCG);
 	
-	DEBUG_COMMAND_YET("SACT.CG_QueryBpp %d,%p:", wNumCG, vBpp);
+	TRACE("SACT.CG_QueryBpp %d,%p:", wNumCG, vBpp);
 }
 
 /**
@@ -812,9 +811,9 @@ static void CG_ExistAlphaMap() {
 	int wNumCG = getCaliValue();
 	int *vMask = getCaliVariable();
 	
-	scg_existalphamap(wNumCG, vMask);
+	*vMask = scg_existalphamap(wNumCG) ? 1 : 0;
 	
-	DEBUG_COMMAND_YET("SACT.CG_ExistAlphaMap %d,%p:", wNumCG, vMask);
+	TRACE("SACT.CG_ExistAlphaMap %d,%p:", wNumCG, vMask);
 }
 
 /**
@@ -839,7 +838,7 @@ static void CG_Create() {
 	
 	scg_create(wNumCG, wWidth, wHeight, wR, wG, wB, wBlendRate);
 	
-	DEBUG_COMMAND_YET("SACT.CG_Create %d,%d,%d,%d,%d,%d,%d:", wNumCG, wWidth, wHeight, wR, wG, wB, wBlendRate);
+	TRACE("SACT.CG_Create %d,%d,%d,%d,%d,%d,%d:", wNumCG, wWidth, wHeight, wR, wG, wB, wBlendRate);
 }
 
 /**
@@ -858,7 +857,7 @@ static void CG_CreateReverse() {
 
 	scg_create_reverse(wNumCG, wNumSrcCG, wReverseX, wReverseY);
 	
-	DEBUG_COMMAND_YET("SACT.CG_CreateReverse %d,%d,%d,%d:", wNumCG, wNumSrcCG, wReverseX, wReverseY);
+	TRACE("SACT.CG_CreateReverse %d,%d,%d,%d:", wNumCG, wNumSrcCG, wReverseX, wReverseY);
 }
 
 /**
@@ -877,7 +876,7 @@ static void CG_CreateStretch() {
 
 	scg_create_stretch(wNumCG, wWidth, wHeight, wNumSrcCG);
 	
-	DEBUG_COMMAND_YET("SACT.CG_CreateStretch %d,%d,%d,%d:", wNumCG, wWidth, wHeight, wNumSrcCG);
+	TRACE("SACT.CG_CreateStretch %d,%d,%d,%d:", wNumCG, wWidth, wHeight, wNumSrcCG);
 }
 
 /**
@@ -898,7 +897,7 @@ static void CG_CreateBlend() {
 	int wNumBlendCG   = getCaliValue();
 	int wAlphaMapMode = getCaliValue();
 	
-	DEBUG_COMMAND_YET("SACT.CG_CreateBlend %d,%d,%d,%d,%d,%d:", wNumDstCG, wNumBaseCG, wX, wY, wNumBlendCG, wAlphaMapMode);
+	TRACE("SACT.CG_CreateBlend %d,%d,%d,%d,%d,%d:", wNumDstCG, wNumBaseCG, wX, wY, wNumBlendCG, wAlphaMapMode);
 	scg_create_blend(wNumDstCG, wNumBaseCG, wX, wY, wNumBlendCG, wAlphaMapMode);
 	
 }
@@ -923,7 +922,7 @@ static void CG_CreateText() {
 	
 	scg_create_text(wNumCG, wSize, wR, wG, wB, wText);
 	
-	DEBUG_COMMAND_YET("SACT.CG_CreateText %d,%d,%d,%d,%d,%d:", wNumCG, wSize, wR, wG, wB, wText);
+	TRACE("SACT.CG_CreateText %d,%d,%d,%d,%d,%d:", wNumCG, wSize, wR, wG, wB, wText);
 }
 
 /**
@@ -951,7 +950,7 @@ static void CG_CreateTextNum() {
 	
 	scg_create_textnum(wNumCG, wSize, wR, wG, wB, wFigs, wZeroPadding, wValue);
 	
-	DEBUG_COMMAND_YET("SACT.CG_CreateTextNum %d,%d,%d,%d,%d,%d,%d,%d:", wNumCG, wSize, wR, wG, wB, wFigs, wZeroPadding, wValue);
+	TRACE("SACT.CG_CreateTextNum %d,%d,%d,%d,%d,%d,%d,%d:", wNumCG, wSize, wR, wG, wB, wFigs, wZeroPadding, wValue);
 }
 
 /**
@@ -966,7 +965,7 @@ static void CG_Copy() {
 	
 	scg_copy(wNumDst, wNumSrc);
 
-	DEBUG_COMMAND_YET("SACT.CG_Copy %d,%d:", wNumDst, wNumSrc);
+	TRACE("SACT.CG_Copy %d,%d:", wNumDst, wNumSrc);
 }
 
 /**
@@ -989,7 +988,7 @@ static void CG_Cut() {
 	
 	scg_cut(wNumDstCG, wNumSrcCG, wX, wY, wWidth, wHeight);
 	
-	DEBUG_COMMAND_YET("SACT.CG_Cut %d,%d,%d,%d,%d,%d:", wNumDstCG, wNumSrcCG, wX, wY, wWidth, wHeight);
+	TRACE("SACT.CG_Cut %d,%d,%d,%d,%d,%d:", wNumDstCG, wNumSrcCG, wX, wY, wWidth, wHeight);
 }
 
 /**
@@ -1013,7 +1012,7 @@ static void CG_PartCopy() {
 	
 	scg_partcopy(wNumDstCG, wNumSrcCG, wX, wY, wWidth, wHeight);
 	
-	DEBUG_COMMAND_YET("SACT.PartCopy %d,%d,%d,%d,%d,%d:", wNumDstCG, wNumSrcCG, wX, wY, wWidth, wHeight);
+	TRACE("SACT.PartCopy %d,%d,%d,%d,%d,%d:", wNumDstCG, wNumSrcCG, wX, wY, wWidth, wHeight);
 }
 
 /**
@@ -1024,10 +1023,10 @@ static void CG_PartCopy() {
 static void WaitKeySimple() {
 	int *vKey = getCaliVariable();
 
-	DEBUG_COMMAND_YET("SACT.WaitKeySimple %d:", vKey);
+	TRACE("SACT.WaitKeySimple %d:", vKey);
 
 	// とりあえず全更新
-	sp_update_all(TRUE);
+	sp_update_all(true);
 	
 	sact.waittype = KEYWAIT_SIMPLE;
 	sact.waitkey = -1;
@@ -1060,7 +1059,7 @@ static void WaitKeyMessage() {
 	
 	smsg_keywait(wMessageMark1, wMessageMark2, wMessageLength);
 	
-	DEBUG_COMMAND_YET("SACT.WaitKeyMessage %d,%d,%d:", wMessageMark1, wMessageMark2, wMessageLength);
+	TRACE("SACT.WaitKeyMessage %d,%d,%d:", wMessageMark1, wMessageMark2, wMessageLength);
 }
 
 /**
@@ -1077,25 +1076,33 @@ static void WaitKeySprite() {
 	int *vRsv1 = getCaliVariable();
 	int *vRsv2 = getCaliVariable();
 	
-	DEBUG_COMMAND("SACT.WaitKeySprite %p,%p,%p,%p:", vOK, vRND, vRsv1, vRsv2);
+	TRACE("SACT.WaitKeySprite %p,%p,%p,%p:", vOK, vRND, vRsv1, vRsv2);
 	
 	sp_keywait(vOK, vRND, vRsv1, vRsv2, NULL, -1);
 	
-	DEBUG_COMMAND_YET("SACT.WaitKeySprite %d,%d,%d,%d:", *vOK, *vRND, *vRsv1, *vRsv2);
+	TRACE("SACT.WaitKeySprite %d,%d,%d,%d:", *vOK, *vRND, *vRsv1, *vRsv2);
 }
 
 /**
  * SACT.PeekKey (1.2~)
- *   ?????
+ *   Get the status of the key
  *   @param nKeyCode:
  *   @param vResult:
  */
 static void PeekKey() {
+	static int prevKeyCode = NUM_KEYCODES;
 	int nKeyCode = getCaliValue();
 	int *vResult = getCaliVariable();
-	
-	WARNING("NOT IMPLEMENTED");
-	DEBUG_COMMAND_YET("SACT.PeekKey %d,%p:", nKeyCode, vResult);
+
+	// This function is called successively with different nKeyCodes.
+	// Only the first call hits the scheduler.
+	if (nKeyCode <= prevKeyCode)
+		sys_getKeyInfo();
+	prevKeyCode = nKeyCode;
+
+	*vResult = RawKeyInfo[nKeyCode] ? 1 : 0;
+
+	TRACE("SACT.PeekKey %d,%p:", nKeyCode, vResult);
 }
 
 /**
@@ -1103,8 +1110,7 @@ static void PeekKey() {
  *   文字送りキーが押されっぱなしの時、離されるまで待つ
  */
 static void WaitMsgSkipKeyUp() {
-	WARNING("NOT IMPLEMENTED");
-	DEBUG_COMMAND_YET("SACT.WaitMsgSkipKeyUp:");
+	TRACE_UNIMPLEMENTED("SACT.WaitMsgSkipKeyUp:");
 }
 
 /**
@@ -1133,7 +1139,7 @@ static void WaitKeySimpleTimeOut() {
 	
 	sact.waittype = KEYWAIT_NONE;
 	
-	DEBUG_COMMAND_YET("SACT.WaitKeySimpleTimeOut %p,%p,%d:", vRND, vD03, wTime);
+	TRACE("SACT.WaitKeySimpleTimeOut %p,%p,%d:", vRND, vD03, wTime);
 }
 
 /**
@@ -1156,7 +1162,7 @@ static void WaitKeySpriteTimeOut() {
 	
 	sp_keywait(vOK, vRND, vD01, vD02, vD03, wTime);
 	
-	DEBUG_COMMAND_YET("SACT.WaitKeySpriteTimeOut %p,%p,%p,%p,%p,%d:", vOK, vRND, vD01, vD02, vD03, wTime);
+	TRACE("SACT.WaitKeySpriteTimeOut %p,%p,%p,%p,%p,%d:", vOK, vRND, vD01, vD02, vD03, wTime);
 }
 
 /**
@@ -1169,7 +1175,7 @@ static void QueryMessageSkip() {
 
 	*vSkip = msgskip_isSkipping() ? 1 : 0;
 	
-	DEBUG_COMMAND_YET("SACT.QueryMessageSkip %p:", vSkip);
+	TRACE("SACT.QueryMessageSkip %p:", vSkip);
 }
 
 /**
@@ -1184,7 +1190,7 @@ static void RegistReplaceString() {
 	
 	sstr_regist_replace(sstr, dstr);
 	
-	DEBUG_COMMAND_YET("SACT.RegistReplaceString %d,%d:", sstr, dstr);
+	TRACE("SACT.RegistReplaceString %d,%d:", sstr, dstr);
 }
 
 /**
@@ -1224,7 +1230,7 @@ static void MessageOutput() {
 	
 	smsg_out(wMessageSpriteNumber, wMessageSize, wMessageColorR, wMessageColorG, wMessageColorB, wMessageFont, wMessageSpeed, wMessageLineSpace, wMessageAlign, 0, 0, 0, vMessageLength);
 	
-	DEBUG_COMMAND_YET("SACT.MessageOutput %d,%d,%d,%d,%d,%d,%d,%d,%d,%p:", wMessageSpriteNumber, wMessageSize, wMessageColorR, wMessageColorG, wMessageColorB, wMessageFont, wMessageSpeed, wMessageLineSpace, wMessageAlign, vMessageLength);
+	TRACE("SACT.MessageOutput %d,%d,%d,%d,%d,%d,%d,%d,%d,%p:", wMessageSpriteNumber, wMessageSize, wMessageColorR, wMessageColorG, wMessageColorB, wMessageFont, wMessageSpeed, wMessageLineSpace, wMessageAlign, vMessageLength);
 }
 
 /**
@@ -1268,7 +1274,7 @@ static void MessageOutputEx() {
 	
 	smsg_out(wMessageSpriteNumber, wMessageSize, wMessageColorR, wMessageColorG, wMessageColorB, wMessageFont, wMessageSpeed, wMessageLineSpace, wMessageAlign, wRubySize, wRubyFont, wRubyLineSpace, vLength);
 	
-	DEBUG_COMMAND_YET("SACT.MessageOutputEx %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%p:", wMessageSpriteNumber, wMessageSize, wMessageColorR, wMessageColorG, wMessageColorB, wMessageFont, wMessageSpeed, wMessageLineSpace,wMessageAlign, wRubySize, wRubyFont, wRubyLineSpace, vLength);
+	TRACE("SACT.MessageOutputEx %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%p:", wMessageSpriteNumber, wMessageSize, wMessageColorR, wMessageColorG, wMessageColorB, wMessageFont, wMessageSpeed, wMessageLineSpace,wMessageAlign, wRubySize, wRubyFont, wRubyLineSpace, vLength);
 }
 
 /**
@@ -1283,7 +1289,7 @@ static void MessageNewLine() {
 	
 	smsg_newline(wMessageSpriteNumber, wMessageSize);
 	
-	DEBUG_COMMAND_YET("SACT.MessageNewLine %d,%d:", wMessageSpriteNumber, wMessageSize);
+	TRACE("SACT.MessageNewLine %d,%d:", wMessageSpriteNumber, wMessageSize);
 }
 
 /**
@@ -1296,7 +1302,7 @@ static void MessageClear() {
 	
 	smsg_clear(wMessageSpriteNumber);
 	
-	DEBUG_COMMAND_YET("SACT.MessageClear %d:", wMessageSpriteNumber);
+	TRACE("SACT.MessageClear %d:", wMessageSpriteNumber);
 }
 
 /**
@@ -1307,9 +1313,9 @@ static void MessageClear() {
 static void MessageIsEmpty() {
 	int *wResult = getCaliVariable();
 
-	*wResult = smsg_is_empty();
+	*wResult = smsg_is_empty() ? 1 : 0;
 	
-	DEBUG_COMMAND_YET("SACT.MessageIsEmpty %p:", wResult);
+	TRACE("SACT.MessageIsEmpty %p:", wResult);
 }
 
 /**
@@ -1322,9 +1328,9 @@ static void MessagePeek() {
 	int *vCount = getCaliVariable();
 	int nTopStringNum = getCaliValue();
 
-	WARNING("NOT IMPLEMENTED");
-	
-	DEBUG_COMMAND_YET("SACT.MessagePeek %p,%d:", vCount, nTopStringNum);
+	*vCount = smsg_peek(nTopStringNum);
+
+	TRACE("SACT.MessagePeek %p,%d:", vCount, nTopStringNum);
 }
 
 /**
@@ -1332,8 +1338,8 @@ static void MessagePeek() {
  *   ログ採取停止
  */
 static void Log_Stop() {
-	sact.logging = FALSE;
-	DEBUG_COMMAND_YET("SACT.Log_Stop:");
+	sact.logging = false;
+	TRACE("SACT.Log_Stop:");
 }
 
 /**
@@ -1341,8 +1347,8 @@ static void Log_Stop() {
  *   ログ採取開始
  */
 static void Log_Start() {
-	sact.logging = TRUE;
-	DEBUG_COMMAND_YET("SACT.Log_Start:");
+	sact.logging = true;
+	TRACE("SACT.Log_Start:");
 }
 
 /**
@@ -1352,7 +1358,7 @@ static void Log_Start() {
 static void MenuClear() {
 	ssel_clear();
 	
-	DEBUG_COMMAND_YET("SACT.MenuClear:");
+	TRACE("SACT.MenuClear:");
 }
 
 /**
@@ -1367,7 +1373,7 @@ static void MenuAdd() {
 
 	ssel_add(nString, wI);
 	
-	DEBUG_COMMAND_YET("SACT.MenuAdd %d,%d:", nString, wI);
+	TRACE("SACT.MenuAdd %d,%d:", nString, wI);
 }
 
 /**
@@ -1396,7 +1402,7 @@ static void MenuOpen() {
 	
 	*wMenuResult = ssel_select(wNum, wChoiceSize, wMenuOutSpc, wChoiceLineSpace, wChoiceAutoMoveCursor, nAlign);
 	
-	DEBUG_COMMAND_YET("SACT.MenuOpen %p,%d,%d,%d,%d,%d,%d:", wMenuResult, wNum, wChoiceSize, wMenuOutSpc, wChoiceLineSpace, wChoiceAutoMoveCursor, nAlign);
+	TRACE("SACT.MenuOpen %p,%d,%d,%d,%d,%d,%d:", wMenuResult, wNum, wChoiceSize, wMenuOutSpc, wChoiceLineSpace, wChoiceAutoMoveCursor, nAlign);
 }
 
 /**
@@ -1409,7 +1415,7 @@ static void PushString() {
 	
 	sstr_push(nString);
 	
-	DEBUG_COMMAND_YET("SACT.PushString %d:", nString);
+	TRACE("SACT.PushString %d:", nString);
 }
 
 /**
@@ -1422,7 +1428,7 @@ static void PopString() {
 
 	sstr_pop(nString);
 	
-	DEBUG_COMMAND_YET("SACT.PopString %d:", nString);
+	TRACE("SACT.PopString %d:", nString);
 }
 
 /**
@@ -1445,7 +1451,7 @@ static void Numeral_SetCG() {
 	
 	sp_num_setcg(nNum, nIndex, nCG);
 	
-	DEBUG_COMMAND_YET("SACT.Numeral_SetCG %d,%d,%d:", nNum, nIndex, nCG);
+	TRACE("SACT.Numeral_SetCG %d,%d,%d:", nNum, nIndex, nCG);
 }
 
 /**
@@ -1462,7 +1468,7 @@ static void Numeral_GetCG() {
 	
 	sp_num_getcg(nNum, nIndex, vCG);
 	
-	DEBUG_COMMAND_YET("SACT.Numeral_GetCG %d,%d,%p:", nNum, nIndex, vCG);
+	TRACE("SACT.Numeral_GetCG %d,%d,%p:", nNum, nIndex, vCG);
 }
 
 /**
@@ -1479,7 +1485,7 @@ static void Numeral_SetPos() {
 	
 	sp_num_setpos(nNum, nX, nY);
 	
-	DEBUG_COMMAND_YET("SACT.Numeral_SetPos %d,%d,%d:", nNum, nX, nY);
+	TRACE("SACT.Numeral_SetPos %d,%d,%d:", nNum, nX, nY);
 }
 
 /**
@@ -1496,7 +1502,7 @@ static void Numeral_GetPos() {
 	
 	sp_num_getpos(nNum, vX, vY);
 	
-	DEBUG_COMMAND_YET("SACT.Numeral_GetPos %d,%p,%p:", nNum, vX, vY);
+	TRACE("SACT.Numeral_GetPos %d,%p,%p:", nNum, vX, vY);
 }
 
 /**
@@ -1511,7 +1517,7 @@ static void Numeral_SetSpan() {
 	
 	sp_num_setspan(nNum, nSpan);
 	
-	DEBUG_COMMAND_YET("SACT.Numeral_SetSpan %d,%d:", nNum, nSpan);
+	TRACE("SACT.Numeral_SetSpan %d,%d:", nNum, nSpan);
 }
 
 /**
@@ -1526,7 +1532,7 @@ static void Numeral_GetSpan() {
 
 	sp_num_getspan(nNum, vSpan);
 	
-	DEBUG_COMMAND_YET("SACT.Numeral_GetSpan %d,%p:", nNum, vSpan);
+	TRACE("SACT.Numeral_GetSpan %d,%p:", nNum, vSpan);
 }
 
 /**
@@ -1534,7 +1540,7 @@ static void Numeral_GetSpan() {
  *   説明スプライト設定クリア
  */
 static void ExpSp_Clear() {
-	DEBUG_COMMAND_YET("SACT.ExpSp_Clear:");
+	TRACE("SACT.ExpSp_Clear:");
 
 	sp_exp_clear();
 }
@@ -1551,7 +1557,7 @@ static void ExpSp_Add() {
 	
 	sp_exp_add(wNumSP1, wNumSP2);
 	
-	DEBUG_COMMAND_YET("SACT.ExpSp_Add %d,%d:", wNumSP1, wNumSP2);
+	TRACE("SACT.ExpSp_Add %d,%d:", wNumSP1, wNumSP2);
 }
 
 /**
@@ -1564,7 +1570,7 @@ static void ExpSp_Del() {
 	
 	sp_exp_del(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.ExpSp_Del %d:", wNum);
+	TRACE("SACT.ExpSp_Del %d:", wNum);
 }
 
 /**
@@ -1579,7 +1585,7 @@ static void TimerSet() {
 	
 	stimer_reset(wTimerID, wCount);
 	
-	DEBUG_COMMAND("SACT.TimerSet %d,%d:", wTimerID, wCount);
+	TRACE("SACT.TimerSet %d,%d:", wTimerID, wCount);
 }
 
 /**
@@ -1594,7 +1600,7 @@ static void TimerGet() {
 
 	*vRND = stimer_get(wTimerID);
 	
-	DEBUG_COMMAND("SACT.TimerGet %d,%p:", wTimerID, vRND);
+	TRACE("SACT.TimerGet %d,%p:", wTimerID, vRND);
 }
 
 /**
@@ -1611,7 +1617,7 @@ static void TimerWait() {
 		sys_keywait(10, KEYWAIT_NONCANCELABLE);
 	}
 	
-	DEBUG_COMMAND("SACT.TimerWait %d,%d:", wTimerID, wCount);
+	TRACE("SACT.TimerWait %d,%d:", wTimerID, wCount);
 }
 
 /**
@@ -1624,7 +1630,7 @@ static void Wait() {
 	
 	sys_keywait(wCount*10, KEYWAIT_NONCANCELABLE);
 	
-	DEBUG_COMMAND_YET("SACT.Wait %d:", wCount);
+	TRACE("SACT.Wait %d:", wCount);
 }
 
 /**
@@ -1637,7 +1643,7 @@ static void SoundPlay() {
 	
 	ssnd_play(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.SoundPlay %d:", wNum);
+	TRACE("SACT.SoundPlay %d:", wNum);
 }
 
 /**
@@ -1652,7 +1658,7 @@ static void SoundStop() {
 	
 	ssnd_stop(wNum, wFadeTime);
 	
-	DEBUG_COMMAND_YET("SACT.SoundStop %d,%d:", wNum, wFadeTime);
+	TRACE("SACT.SoundStop %d,%d:", wNum, wFadeTime);
 }
 
 /**
@@ -1666,7 +1672,7 @@ static void SoundStopAll() {
 	
 	ssnd_stopall(wFadeTime);
 	
-	DEBUG_COMMAND_YET("SACT.SoundStopAll %d:", wFadeTime);
+	TRACE("SACT.SoundStopAll %d:", wFadeTime);
 }
 
 /**
@@ -1679,7 +1685,7 @@ static void SoundWait() {
 	
 	ssnd_wait(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.SoundWait %d:", wNum);
+	TRACE("SACT.SoundWait %d:", wNum);
 }
 
 /**
@@ -1694,7 +1700,7 @@ static void SoundWaitKey() {
 	
 	ssnd_waitkey(wNum, vKey);
 	
-	DEBUG_COMMAND_YET("SACT.SoundWaitKey %d,%p:", wNum, vKey);
+	TRACE("SACT.SoundWaitKey %d,%p:", wNum, vKey);
 }
 
 /**
@@ -1707,7 +1713,7 @@ static void SoundPrepare() {
 	
 	ssnd_prepare(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.SoundPrepare %d:", wNum);
+	TRACE("SACT.SoundPrepare %d:", wNum);
 }
 
 /**
@@ -1720,7 +1726,7 @@ static void SoundPrepareLR() {
 
 	ssnd_prepareLRrev(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.SoundPrepareLR %d:", wNum);
+	TRACE("SACT.SoundPrepareLR %d:", wNum);
 }
 
 /**
@@ -1733,7 +1739,7 @@ static void SoundPlayLR() {
 	
 	ssnd_playLRrev(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.SoundPlayLR %d:", wNum);
+	TRACE("SACT.SoundPlayLR %d:", wNum);
 }
 
 /**
@@ -1757,7 +1763,7 @@ static void SpriteSound() {
 		sp_sound_set(i, wNumWave1, wNumWave2, wNumWave3);
 	}
 	
-	DEBUG_COMMAND_YET("SACT.SpriteSound %d,%d,%d,%d,%d:", wNumSP, nCount, wNumWave1, wNumWave2, wNumWave3);
+	TRACE("SACT.SpriteSound %d,%d,%d,%d,%d:", wNumSP, nCount, wNumWave1, wNumWave2, wNumWave3);
 }
 
 /**
@@ -1765,7 +1771,7 @@ static void SpriteSound() {
  *   SpriteSoundで設定したすべての音の再生終了まで待つ (~SP_SOUND_WAIT)
  */
 static void SpriteSoundWait() {
-	DEBUG_COMMAND_YET("SACT.SpriteSoundWait:");
+	TRACE("SACT.SpriteSoundWait:");
 
 	sp_sound_wait();
 }
@@ -1780,7 +1786,7 @@ static void SpriteSoundOB() {
 	
 	sp_sound_ob(wNumWave);
 	
-	DEBUG_COMMAND_YET("SACT.SpriteSoundOB %d:", wNumWave);
+	TRACE("SACT.SpriteSoundOB %d:", wNumWave);
 }
 
 /**
@@ -1793,11 +1799,9 @@ static void MusicCheck() {
 	int wNum = getCaliValue();
 	int *vRND = getCaliVariable();
 	
-	dridata *dfile = ald_getdata(DRIFILE_BGM, wNum - 1);
-	*vRND = dfile ? 1 : 0;
-	ald_freedata(dfile);
+	*vRND = ald_exists(DRIFILE_BGM, wNum - 1) ? 1 : 0;
 	
-	DEBUG_COMMAND_YET("SACT.MusicCheck %d,%p:", wNum, vRND);
+	TRACE("SACT.MusicCheck %d,%p:", wNum, vRND);
 }
 
 /**
@@ -1812,7 +1816,7 @@ static void MusicGetLength() {
 	
 	*vRND = musbgm_getlen(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.MusicGetLength %d,%d:", wNum, *vRND);
+	TRACE("SACT.MusicGetLength %d,%d:", wNum, *vRND);
 }
 
 /**
@@ -1827,7 +1831,7 @@ static void MusicGetPos() {
 	
 	*vRND = musbgm_getpos(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.MusicGetPos %d,%d:", wNum, *vRND);
+	TRACE("SACT.MusicGetPos %d,%d:", wNum, *vRND);
 }
 
 /**
@@ -1842,9 +1846,9 @@ static void MusicPlay() {
 	int wFadeTime = getCaliValue();
 	int wVolume = getCaliValue();
 	
-	musbgm_play(wNum, wFadeTime, wVolume);
+	musbgm_play(wNum, wFadeTime, wVolume, 0);
 	
-	DEBUG_COMMAND_YET("SACT.MusicPlay %d,%d,%d:", wNum, wFadeTime, wVolume);
+	TRACE("SACT.MusicPlay %d,%d,%d:", wNum, wFadeTime, wVolume);
 }
 
 /**
@@ -1859,7 +1863,7 @@ static void MusicStop() {
 	
 	musbgm_stop(wNum, wFadeTime);
 	
-	DEBUG_COMMAND_YET("SACT.MusicStop %d,%d:", wNum, wFadeTime);
+	TRACE("SACT.MusicStop %d,%d:", wNum, wFadeTime);
 }
 
 /**
@@ -1872,7 +1876,7 @@ static void MusicStopAll() {
 	
 	musbgm_stopall(wFadeTime);
 	
-	DEBUG_COMMAND_YET("SACT.MusicStopAll %d:", wFadeTime);
+	TRACE("SACT.MusicStopAll %d:", wFadeTime);
 }
 
 /**
@@ -1889,7 +1893,7 @@ static void MusicFade() {
 	
 	musbgm_fade(wNum, wFadeTime, wVolume);
 	
-	DEBUG_COMMAND_YET("SACT.MusicFade %d,%d,%d:", wNum, wFadeTime, wVolume);
+	TRACE("SACT.MusicFade %d,%d,%d:", wNum, wFadeTime, wVolume);
 }
 
 /**
@@ -1908,7 +1912,7 @@ static void MusicWait() {
 	
 	musbgm_wait(wNum, nTimeOut);
 	
-	DEBUG_COMMAND_YET("SACT.MusicWait %d,%d:", wNum, nTimeOut);
+	TRACE("SACT.MusicWait %d,%d:", wNum, nTimeOut);
 }
 
 /**
@@ -1921,10 +1925,8 @@ static void MusicWait() {
 static void MusicWaitPos() {
 	int wNum = getCaliValue();
 	int wIndex = getCaliValue();
-	
-	WARNING("SACT.MusicWatiPos not implemented");
-	
-	DEBUG_COMMAND_YET("SACT.MusicWaitPos %d,%d:", wNum, wIndex);
+
+	TRACE_UNIMPLEMENTED("SACT.MusicWaitPos %d,%d:", wNum, wIndex);
 }
 
 /**
@@ -1939,7 +1941,7 @@ static void SoundGetLinkNum() {
 
 	*vRND = ssnd_getlinknum(wNum);
 	
-	DEBUG_COMMAND_YET("SACT.SoundGetLinkNum %d,%p:", wNum, vRND);
+	TRACE("SACT.SoundGetLinkNum %d,%p:", wNum, vRND);
 }
 
 /**
@@ -1964,7 +1966,7 @@ static void ChartPos() {
 	
 	schart_pos(pos, pos1, pos2, val1, val2, val);
 	
-	DEBUG_COMMAND_YET("SACT.ChartPos %p,%d,%d,%d,%d,%d:", pos, pos1, pos2, val1, val2, val);
+	TRACE("SACT.ChartPos %p,%d,%d,%d,%d,%d:", pos, pos1, pos2, val1, val2, val);
 }
 
 /**
@@ -1983,7 +1985,7 @@ static void NumToStr() {
 	
 	sstr_num2str(strno, fig, zeropad, num);
 	
-	DEBUG_COMMAND_YET("SACT.NumToStr %d,%d,%d,%d:", strno, fig, zeropad, num);
+	TRACE("SACT.NumToStr %d,%d,%d,%d:", strno, fig, zeropad, num);
 }
 
 /**
@@ -1993,9 +1995,7 @@ static void Maze_Create() {
 	int p1 = getCaliValue();
 	int p2 = getCaliValue();
 
-	WARNING("NOT IMPLEMENTED");
-	
-	DEBUG_COMMAND_YET("SACT.Maze_Create %d,%d:", p1,p2);
+	TRACE_UNIMPLEMENTED("SACT.Maze_Create %d,%d:", p1,p2);
 }
 
 /**
@@ -2005,10 +2005,8 @@ static void Maze_Get() {
 	int *p1 = getCaliVariable();
 	int p2 = getCaliValue();
 	int p3 = getCaliValue();
-	
-	WARNING("NOT IMPLEMENTED");
-	
-	DEBUG_COMMAND_YET("SACT.Maze_Get %p,%d,%d:", p1,p2,p3);
+
+	TRACE_UNIMPLEMENTED("SACT.Maze_Get %p,%d,%d:", p1,p2,p3);
 }
 
 /**
@@ -2021,7 +2019,7 @@ static void EncryptWORD() {
 
 	scryp_encrypt_word(array, num, key);
 	
-	DEBUG_COMMAND_YET("SACT.EncryptWORD %p,%d,%d:", array, num, key);
+	TRACE("SACT.EncryptWORD %p,%d,%d:", array, num, key);
 }
 
 /**
@@ -2034,7 +2032,7 @@ static void DecryptWORD() {
 
 	scryp_encrypt_word(array, num, key);
 	
-	DEBUG_COMMAND_YET("SACT.DecryptWORD %p,%d,%d:", array, num, key);
+	TRACE("SACT.DecryptWORD %p,%d,%d:", array, num, key);
 }
 
 /**
@@ -2046,7 +2044,7 @@ static void EncryptString() {
 
 	scryp_encrypt_str(p1, p2);
 	
-	DEBUG_COMMAND_YET("SACT.EncryptString %d,%d:", p1,p2);
+	TRACE("SACT.EncryptString %d,%d:", p1,p2);
 }
 
 /**
@@ -2058,7 +2056,7 @@ static void DecryptString() {
 
 	scryp_decrypt_str(p1, p2);
 	
-	DEBUG_COMMAND_YET("SACT.DecryptString %d,%d:", p1,p2);
+	TRACE("SACT.DecryptString %d,%d:", p1,p2);
 }
 
 /**
@@ -2068,7 +2066,7 @@ static void DecryptString() {
 static void XMenuClear() {
 	spxm_clear();
 	
-	DEBUG_COMMAND_YET("SACT.XMenuClear:");
+	TRACE("SACT.XMenuClear:");
 }
 
 /**
@@ -2083,7 +2081,7 @@ static void XMenuRegister() {
 	
 	spxm_register(nRegiNum, nMenuID);
 	
-	DEBUG_COMMAND_YET("SACT.XMenuRegister %d,%d:", nRegiNum, nMenuID);
+	TRACE("SACT.XMenuRegister %d,%d:", nRegiNum, nMenuID);
 }
 
 /**
@@ -2098,7 +2096,7 @@ static void XMenuGetNum() {
 	
 	*vMenuID = spxm_getnum(nRegiNum);
 	
-	DEBUG_COMMAND_YET("SACT.XMenuGetNum %d,%p:", nRegiNum, vMenuID);
+	TRACE("SACT.XMenuGetNum %d,%p:", nRegiNum, vMenuID);
 }
 
 /**
@@ -2113,7 +2111,7 @@ static void XMenuGetText() {
 	
 	spxm_gettext(nRegiNum, strno);
 	
-	DEBUG_COMMAND_YET("SACT.XMenuGetText %d,%d:", nRegiNum, strno);
+	TRACE("SACT.XMenuGetText %d,%d:", nRegiNum, strno);
 }
 
 /**
@@ -2123,7 +2121,7 @@ static void XMenuGetText() {
 static void XMenuTitleRegister() {
 	spxm_titlereg();
 	
-	DEBUG_COMMAND_YET("SACT.XMenuTitleRegister:");
+	TRACE("SACT.XMenuTitleRegister:");
 }
 
 /**
@@ -2136,7 +2134,7 @@ static void XMenuTitleGet() {
 	
 	spxm_titleget(strno);
 	
-	DEBUG_COMMAND_YET("SACT.XMenuTitleGet %d:", strno);
+	TRACE("SACT.XMenuTitleGet %d:", strno);
 }
 
 static void SACT_reset(void) {
@@ -2147,7 +2145,7 @@ static void SACT_reset(void) {
 	sp_reset();
 
 	scg_freeall();
-	sf_free(sact.dmap);
+	SDL_FreeSurface(sact.dmap);
 	memset(&sact, 0, sizeof(sact));
 }
 
