@@ -24,9 +24,9 @@
 #ifndef __SACTCRYPT_H__
 #define __SACTCRYPT_H__
 
-extern int scryp_encrypt_word(int *array, int num, int key);
-extern int scryp_decrypt_word(int *array, int num, int key);
-extern int scryp_encrypt_str(int strno, int key);
-extern int scryp_decrypt_str(int strno, int key);
+void scryp_encrypt_word(int *array, int num, int key);
+void scryp_decrypt_word(int *array, int num, int key);
+void scryp_encrypt_str(int strno, int key);
+void scryp_decrypt_str(int strno, int key);
 
 #endif
