@@ -36,12 +36,13 @@
 #include "nact.h"
 #include "sact.h"
 #include "sprite.h"
-#include "drawtext.h"
-#include "utfsjis.h"
+#include "gfx.h"
+#include "ags.h"
+#include "font.h"
 
 #define LOGMSG_LINES 6
 
-static const char *logmsg_utf8[LOGMSG_LINES] = {
+static char *logmsg[LOGMSG_LINES] = {
 	"\n",
 	"※バックログ操作方法※",
 	"[ESC]またはマウス右クリックでゲームに戻る",
@@ -56,7 +57,7 @@ static const char *logmsg_utf8[LOGMSG_LINES] = {
   PageUP/Downで１ページ送り
 */
 
-#define FONTSIZEINDEX 10
+#define INDEX_FONTSIZE 10
 #define FONTSIZE 20
 #define LOGLINENUM (main_surface->h / FONTSIZE)
 static int curline;
@@ -68,6 +69,10 @@ static void draw_log() {
 	char pinfo[256];
 	List *node;
 
+#ifdef __EMSCRIPTEN__
+	load_mincho_font();
+#endif
+
 	SDL_Surface *hline = SDL_CreateRGBSurfaceWithFormat(0, main_surface->w, 3, 32, SDL_PIXELFORMAT_RGB888);
 	SDL_FillRect(hline, NULL, SDL_MapRGB(hline->format, 255, 255, 255));
 	SDL_SetSurfaceBlendMode(hline, SDL_BLENDMODE_BLEND);
@@ -80,8 +85,8 @@ static void draw_log() {
 	// ページ位置情報
 	len = snprintf(pinfo, sizeof(pinfo) -1, "%d/%d", curline, list_length(sact.log));
 	
-	dt_setfont(FONT_GOTHIC, FONTSIZEINDEX);
-	dt_drawtext_col(main_surface, main_surface->w - FONTSIZEINDEX *len /2, 0, pinfo, 255, 255, 255);
+	ags_setFont(FONT_GOTHIC, INDEX_FONTSIZE);
+	gfx_drawString(main_surface->w - INDEX_FONTSIZE * len / 2, 0, pinfo, 255);
 	
 	// 表示始め位置
 	node = list_nth(sact.log, list_length(sact.log) - curline);
@@ -93,11 +98,11 @@ static void draw_log() {
 			SDL_BlitSurface(hline, NULL, main_surface, &(SDL_Rect){0, y + FONTSIZE/2, main_surface->w, 3});
 		} else {
 			if (cur < 6) {
-				dt_setfont(FONT_MINCHO, FONTSIZE);
+				ags_setFont(FONT_MINCHO, FONTSIZE);
 			} else {
-				dt_setfont(FONT_GOTHIC, FONTSIZE);
+				ags_setFont(FONT_GOTHIC, FONTSIZE);
 			}
-			dt_drawtext_col(main_surface, 0, y, str, 255, 255, 255);
+			gfx_drawString(0, y, str, 255);
 		}
 		y += FONTSIZE;
 		cur--;
@@ -113,13 +118,7 @@ bool sblog_start(void) {
 	if (sact.version < 120)
 		return false;
 
-	static char *logmsg[LOGMSG_LINES];
-	if (!logmsg[0]) {
-		for (int i = 0; i < LOGMSG_LINES; i++)
-			logmsg[i] = fromUTF8(logmsg_utf8[i]);
-	}
-
-	// 説明文章を追加
+	// Append instruction text
 	for (int i = 0; i < LOGMSG_LINES; i++)
 		sact.log = list_append(sact.log, logmsg[i]);
 	
@@ -138,10 +137,9 @@ void sblog_end(void) {
 	
 	SDL_FreeSurface(back);
 
-	// 説明文章を削除
+	// Remove instruction text
 	for (i = 0; i < LOGMSG_LINES; i++) {
-		node = list_last(sact.log);
-		sact.log = list_remove(sact.log, node->data);
+		sact.log = list_remove(sact.log, logmsg[i]);
 	}
 }
 
