@@ -29,24 +29,24 @@ static void Init() {
 	dd.alk = alk_new("/home/masaki-c/game/daiakuji/dDemo.alk");
 #endif
 	
-	DEBUG_COMMAND_YET("dDemo.Init %d,%d,%d,%p:", p1, p2, p3, var);
+	TRACE_UNIMPLEMENTED("dDemo.Init %d,%d,%d,%p:", p1, p2, p3, var);
 }
 
 static void SetKeyCancelFlag() {
 	int cancelflag = getCaliValue();
 	
-	DEBUG_COMMAND_YET("dDemo.SetKeyCancelFlag %d:", cancelflag);
+	TRACE_UNIMPLEMENTED("dDemo.SetKeyCancelFlag %d:", cancelflag);
 }
 
 static void SetLoopFlag() {
 	/* Loop Flag */
 	int loopflag = getCaliValue(); /* 0 なら無限繰り返し */
 	
-	DEBUG_COMMAND_YET("dDemo.SetLoopFlag %d:", loopflag);
+	TRACE_UNIMPLEMENTED("dDemo.SetLoopFlag %d:", loopflag);
 }
 
 static void Run() {
-	DEBUG_COMMAND_YET("dDemo.Run:");
+	TRACE_UNIMPLEMENTED("dDemo.Run:");
 	
 #ifdef DDEMODEV
 	muscd_start(13, 1);
