@@ -35,7 +35,9 @@
 #include "xsystem35.h"
 #include "scenario.h"
 #include "ags.h"
-#include "sdl_core.h"
+#include "gfx.h"
+#include "effect.h"
+#include "event.h"
 #include "alpha_plane.h"
 #include "utfsjis.h"
 #include "input.h"
@@ -81,25 +83,25 @@ static void initPal(void) {
 	for (int i = 0; i < 256; i++) {
 		nact->ags.pal[i].a = 255;
 	}
-	sdl_setPalette(nact->ags.pal, 0, 256);
+	gfx_setPalette(nact->ags.pal, 0, 256);
 	palette_changed();
 }
 
 bool ags_check_param(int *x, int *y, int *w, int *h) {
-	if (*x >= nact->ags.world_size.width) {
-		WARNING("Illegal Param x = %d (max=%d)(@%03x:%05x)", *x, nact->ags.world_size.width, sl_getPage(), sl_getIndex());
+	if (*x >= nact->ags.world_width) {
+		WARNING("Illegal Param x = %d (max=%d)(@%03x:%05x)", *x, nact->ags.world_width, sl_getPage(), sl_getIndex());
 		return false;
 	}
-	if (*y >= nact->ags.world_size.height) {
-		WARNING("Illegal Param y = %d (max=%d)", *y, nact->ags.world_size.height);
+	if (*y >= nact->ags.world_height) {
+		WARNING("Illegal Param y = %d (max=%d)", *y, nact->ags.world_height);
 		return false;
 	}
 	
 	if (*x < 0) { *w += *x; *x = 0; }
 	if (*y < 0) { *h += *y; *y = 0; }
 	
-	if ((*x + *w) > nact->ags.world_size.width)  { *w = nact->ags.world_size.width  - *x;}
-	if ((*y + *h) > nact->ags.world_size.height) { *h = nact->ags.world_size.height - *y;}
+	if ((*x + *w) > nact->ags.world_width)  { *w = nact->ags.world_width  - *x;}
+	if ((*y + *h) > nact->ags.world_height) { *h = nact->ags.world_height - *y;}
 	
 	if (*w <= 0) return false;
 	if (*h <= 0) return false;
@@ -108,11 +110,11 @@ bool ags_check_param(int *x, int *y, int *w, int *h) {
 }
 
 bool ags_check_param_xy(int *x, int *y) {
-	if (*x >= nact->ags.world_size.width) {
+	if (*x >= nact->ags.world_width) {
 		WARNING("Illegal Param x = %d", *x);
 		return false;
 	}
-	if (*y >= nact->ags.world_size.height) {
+	if (*y >= nact->ags.world_height) {
 		WARNING("Illegal Param y = %d", *y);
 		return false;
 	}
@@ -125,8 +127,8 @@ bool ags_check_param_xy(int *x, int *y) {
 
 void ags_init(const char *render_driver, bool enable_zb) {
 	nact->ags.mouse_warp_enabled = true;
-	nact->ags.world_size.width  =  SYS35_DEFAULT_WIDTH;
-	nact->ags.world_size.height =  SYS35_DEFAULT_HEIGHT;
+	nact->ags.world_width  =  SYS35_DEFAULT_WIDTH;
+	nact->ags.world_height =  SYS35_DEFAULT_HEIGHT;
 	nact->ags.world_depth =  SYS35_DEFAULT_DEPTH;
 	nact->ags.view_area.x = 0;
 	nact->ags.view_area.y = 0;
@@ -139,7 +141,9 @@ void ags_init(const char *render_driver, bool enable_zb) {
 	nact->ags.enable_zb = enable_zb;
 	nact->ags.font_weight = enable_zb ? FONT_WEIGHT_BOLD : FONT_WEIGHT_NORMAL;
 	
-	sdl_Initialize(render_driver);
+	gfx_Initialize(render_driver);
+	event_init();
+	cursor_init();
 	font_init();
 
 	initPal();
@@ -148,7 +152,8 @@ void ags_init(const char *render_driver, bool enable_zb) {
 
 void ags_remove(void) {
 	ags_autorepeat(true);
-	sdl_Remove();
+	event_remove();
+	gfx_Remove();
 }
 
 void ags_reset(void) {
@@ -159,8 +164,8 @@ void ags_reset(void) {
 }
 
 void ags_setWorldSize(int width, int height, int depth) {
-	nact->ags.world_size.width  = width;
-	nact->ags.world_size.height = height;
+	nact->ags.world_width  = width;
+	nact->ags.world_height = height;
 	nact->ags.world_depth       = depth;
 
 	if (nact->ags.dib && nact->ags.dib->alpha) {
@@ -168,9 +173,9 @@ void ags_setWorldSize(int width, int height, int depth) {
 		nact->ags.dib->alpha = NULL;
 	}
 
-	sdl_setWorldSize(width, height, depth);
+	gfx_setWorldSize(width, height, depth);
 	
-	nact->ags.dib = sdl_getDIB();
+	nact->ags.dib = gfx_getDIB();
 	
 	/* DIBが8以上の場合は、alpha plane を用意 */
 	if (depth > 8) {
@@ -188,29 +193,29 @@ void ags_setViewArea(int x, int y, int width, int height) {
 	nact->ags.view_area.y = y;
 	nact->ags.view_area.w = width;
 	nact->ags.view_area.h = height;
-	sdl_setWindowSize(width, height);
+	gfx_setWindowSize(width, height);
 }
 
 void ags_setWindowTitle(const char *title_utf8) {
 	char buf[256];
 	snprintf(buf, sizeof(buf), "XSystem35 Version %s: %s", VERSION, title_utf8);
-	sdl_setWindowTitle(buf);
+	gfx_setWindowTitle(buf);
 }
 
 void ags_getDIBInfo(DispInfo *info) {
-	info->width  = nact->ags.world_size.width;
-	info->height = nact->ags.world_size.height;
+	info->width  = nact->ags.world_width;
+	info->height = nact->ags.world_height;
 	info->depth  = nact->ags.world_depth;
 }
 
 void ags_getViewAreaInfo(DispInfo *info) {
-	sdl_getWindowInfo(info);
+	gfx_getWindowInfo(NULL, NULL, &info->depth);
 	info->width  = nact->ags.view_area.w;
 	info->height = nact->ags.view_area.h;
 }
 
 void ags_getWindowInfo(DispInfo *info) {
-	sdl_getWindowInfo(info);
+	gfx_getWindowInfo(&info->width, &info->height, &info->depth);
 }
 
 void ags_setExposeSwitch(bool expose) {
@@ -221,13 +226,13 @@ void ags_updateArea(int x, int y, int w, int h) {
 	if (fade_outed || !need_update)
 		return;
 
-	MyRectangle r = {x, y, w, h}, update;
+	SDL_Rect r = {x, y, w, h}, update;
 	if (SDL_IntersectRect(&nact->ags.view_area, &r, &update)) {
-		MyPoint p = {
+		SDL_Point p = {
 			update.x - nact->ags.view_area.x,
 			update.y - nact->ags.view_area.y
 		};
-		sdl_updateArea(&update, &p);
+		gfx_updateArea(&update, &p);
 	}
 }
 
@@ -235,14 +240,14 @@ void ags_updateFull() {
 	if (fade_outed || !need_update)
 		return;
 
-	MyRectangle r = {
+	SDL_Rect r = {
 		nact->ags.view_area.x,
 		nact->ags.view_area.y,
-		min(nact->ags.view_area.w, nact->ags.world_size.width),
-		min(nact->ags.view_area.h, nact->ags.world_size.height)
+		min(nact->ags.view_area.w, nact->ags.world_width),
+		min(nact->ags.view_area.h, nact->ags.world_height)
 	};
-	MyPoint p = {0, 0};
-	sdl_updateArea(&r, &p);
+	SDL_Point p = {0, 0};
+	gfx_updateArea(&r, &p);
 }
 
 void ags_setPalettes(SDL_Color *src, int dst, int cnt) {
@@ -261,47 +266,47 @@ void ags_setPalette(int no, int red, int green, int blue) {
 
 void ags_setPaletteToSystem(int src, int cnt) {
 	if (!fade_outed) 
-		sdl_setPalette(nact->ags.pal, src, cnt);
+		gfx_setPalette(nact->ags.pal, src, cnt);
 }
 
 void ags_drawRectangle(int x, int y, int w, int h, int col) {
 	if (!ags_check_param(&x, &y, &w, &h)) return;
 	
-	sdl_drawRectangle(x, y, w, h, col);
+	gfx_drawRectangle(x, y, w, h, col);
 }
 
 void ags_fillRectangle(int x, int y, int w, int h, int col) {
 	if (!ags_check_param(&x, &y, &w, &h)) return;
 
-	sdl_fillRectangle(x, y, w, h, col);
+	gfx_fillRectangle(x, y, w, h, col);
 }
 
 void ags_drawLine(int x0, int y0, int x1, int y1, int col) {
 	if (!ags_check_param_xy(&x0, &y0)) return;
 	if (!ags_check_param_xy(&x1, &y1)) return;
 
-	sdl_drawLine(x0, y0, x1, y1, col);
+	gfx_drawLine(x0, y0, x1, y1, col);
 }
 
 void ags_copyArea(int sx, int sy, int w, int h, int dx, int dy) {
 	if (!ags_check_param(&sx, &sy, &w, &h)) return;
 	if (!ags_check_param(&dx, &dy, &w, &h)) return;
 	
-	sdl_copyArea(sx, sy, w, h, dx, dy);
+	gfx_copyArea(sx, sy, w, h, dx, dy);
 }
 
 void ags_scaledCopyArea(int sx, int sy, int sw, int sh, int dx, int dy, int dw, int dh, int mirror_sw) {
 	if (!ags_check_param(&sx, &sy, &sw, &sh)) return;
 	if (!ags_check_param(&dx, &dy, &dw, &dh)) return;
 	
-	sdl_scaledCopyArea(sx, sy, sw, sh, dx, dy, dw, dh, mirror_sw);
+	gfx_scaledCopyArea(sx, sy, sw, sh, dx, dy, dw, dh, mirror_sw);
 }
 
 void ags_copyAreaSP(int sx, int sy, int w, int h, int dx, int dy, int col) {
 	if (!ags_check_param(&sx, &sy, &w, &h)) return;
 	if (!ags_check_param(&dx, &dy, &w, &h)) return;
 
-	sdl_copyAreaSP(sx, sy, w, h, dx, dy, col);
+	gfx_copyAreaSP(sx, sy, w, h, dx, dy, col);
 }
 
 void ags_wrapColor(int x, int y, int w, int h, int p1, int p2) {
@@ -309,13 +314,18 @@ void ags_wrapColor(int x, int y, int w, int h, int p1, int p2) {
 	
 	if (!ags_check_param(&x, &y, &w, &h)) return;
 	
-	sdl_wrapColor(x, y, w, h, p1, p2);
+	gfx_wrapColor(x, y, w, h, p1, p2);
 }
 
-void ags_getPixel(int x, int y, Palette *cell) {
+void ags_getPixel(int x, int y, PixelColor *cell) {
 	if (!ags_check_param_xy(&x, &y)) return;
 
-	sdl_getPixel(x, y, cell);
+	uint32_t pixel = gfx_getPixel(x, y);
+	if (main_surface->format->BitsPerPixel == 8) {
+		cell->index = pixel;
+	} else {
+		SDL_GetRGB(pixel, main_surface->format, &cell->r, &cell->g, &cell->b);
+	}
 }
 
 void ags_copyPaletteShift(int sx, int sy, int w, int h, int dx, int dy, uint8_t sprite) {
@@ -357,7 +367,7 @@ void ags_changeColorArea(int sx, int sy, int w, int h, int dst, int src, int cnt
 void* ags_saveRegion(int x, int y, int w, int h) {
 	if (!ags_check_param(&x, &y, &w, &h)) return NULL;
 
-	return (void *)sdl_saveRegion(x, y, w, h);
+	return (void *)gfx_saveRegion(x, y, w, h);
 }
 
 void ags_restoreRegion(void *region, int x, int y) {
@@ -365,7 +375,7 @@ void ags_restoreRegion(void *region, int x, int y) {
 	
 	if (!ags_check_param_xy(&x, &y)) return;
 	
-	sdl_restoreRegion(region, x, y);
+	gfx_restoreRegion(region, x, y);
 }
 
 void ags_putRegion(void *region, int x, int y) {
@@ -373,16 +383,16 @@ void ags_putRegion(void *region, int x, int y) {
 	
 	if (!ags_check_param_xy(&x, &y)) return;
 	
-	sdl_putRegion(region, x, y);
+	gfx_putRegion(region, x, y);
 }
 
 void ags_delRegion(void *region) {
 	if (region == NULL) return;
 	
-	sdl_delRegion(region);
+	gfx_delRegion(region);
 }
 
-int ags_drawString(int x, int y, const char *src, int col, MyRectangle *rect_out) {
+int ags_drawString(int x, int y, const char *src, int col, SDL_Rect *rect_out) {
 	if (!ags_check_param_xy(&x, &y)) {
 		if (rect_out) {
 			rect_out->x = x;
@@ -393,7 +403,7 @@ int ags_drawString(int x, int y, const char *src, int col, MyRectangle *rect_out
 		return 0;
 	}
 	
-	MyRectangle adj;
+	SDL_Rect adj;
 	char *utf8 = toUTF8(src);
 	switch(nact->ags.text_decoration_type) {
 	case TEXT_DECORATION_NONE:
@@ -401,46 +411,46 @@ int ags_drawString(int x, int y, const char *src, int col, MyRectangle *rect_out
 		adj.x = 0; adj.y = 0; adj.w = 0; adj.h = 0;
 		break;
 	case TEXT_DECORATION_DROP_SHADOW_BOTTOM:
-		sdl_drawString(x, y +1, utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x, y +1, utf8, nact->ags.text_decoration_color);
 		adj.x = 0; adj.y = 0; adj.w = 0; adj.h = 1;
 		break;
 	case TEXT_DECORATION_DROP_SHADOW_RIGHT:
-		sdl_drawString(x +1, y, utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x +1, y, utf8, nact->ags.text_decoration_color);
 		adj.x = 0; adj.y = 0; adj.w = 1; adj.h = 0;
 		break;
 	case TEXT_DECORATION_DROP_SHADOW_BOTTOM_RIGHT:
-		sdl_drawString(x +1, y +1, utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x +1, y +1, utf8, nact->ags.text_decoration_color);
 		adj.x = 0; adj.y = 0; adj.w = 1; adj.h = 1;
 		break;
 	case TEXT_DECORATION_OUTLINE:
-		sdl_drawString(x -1, y, utf8, nact->ags.text_decoration_color);
-		sdl_drawString(x +1, y, utf8, nact->ags.text_decoration_color);
-		sdl_drawString(x, y -1, utf8, nact->ags.text_decoration_color);
-		sdl_drawString(x, y +1, utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x -1, y, utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x +1, y, utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x, y -1, utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x, y +1, utf8, nact->ags.text_decoration_color);
 		adj.x = -1; adj.y = -1; adj.w = 2; adj.h = 2;
 		break;
 	case TEXT_DECORATION_BOLD_HORIZONTAL:
-		sdl_drawString(x +1, y, utf8, col);
+		gfx_drawString(x +1, y, utf8, col);
 		adj.x = 0; adj.y = 0; adj.w = 1; adj.h = 0;
 		break;
 	case TEXT_DECORATION_BOLD_VERTICAL:
-		sdl_drawString(x, y +1, utf8, col);
+		gfx_drawString(x, y +1, utf8, col);
 		adj.x = 0; adj.y = 0; adj.w = 0; adj.h = 1;
 		break;
 	case TEXT_DECORATION_BOLD_HORIZONTAL_VERTICAL:
-		sdl_drawString(x +1, y +1, utf8, col);
+		gfx_drawString(x +1, y +1, utf8, col);
 		adj.x = 0; adj.y = 0; adj.w = 1; adj.h = 1;
 		break;
 	case TEXT_DECORATION_DROP_SHADOW_OUTLINE:
-		sdl_drawString(x -1, y   , utf8, nact->ags.text_decoration_color);
-		sdl_drawString(x +1, y   , utf8, nact->ags.text_decoration_color);
-		sdl_drawString(x   , y -1, utf8, nact->ags.text_decoration_color);
-		sdl_drawString(x   , y +1, utf8, nact->ags.text_decoration_color);
-		sdl_drawString(x +2, y +2, utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x -1, y   , utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x +1, y   , utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x   , y -1, utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x   , y +1, utf8, nact->ags.text_decoration_color);
+		gfx_drawString(x +2, y +2, utf8, nact->ags.text_decoration_color);
 		adj.x = -1; adj.y = -1; adj.w = 3; adj.h = 3;
 		break;
 	}
-	SDL_Rect r = sdl_drawString(x, y, utf8, col);
+	SDL_Rect r = gfx_drawString(x, y, utf8, col);
 	if (rect_out) {
 		rect_out->x = r.x + adj.x;
 		rect_out->y = r.y + adj.y;
@@ -461,13 +471,13 @@ SDL_Surface *ags_drawStringToSurface(const char *str, int r, int g, int b) {
 void ags_drawCg(cgdata *cg, int x, int y, int brightness, int sprite_color, bool alpha_blend) {
 	switch (cg->depth) {
 	case 8:
-		sdl_drawImage8(cg, x, y, sprite_color);
+		gfx_drawImage8(cg, x, y, sprite_color);
 		break;
 	case 16:
-		sdl_drawImage16(cg, nact->ags.dib, x, y, brightness, alpha_blend);
+		gfx_drawImage16(cg, nact->ags.dib, x, y, brightness, alpha_blend);
 		break;
 	case 24:
-		sdl_drawImage24(cg, nact->ags.dib, x, y, brightness);
+		gfx_drawImage24(cg, nact->ags.dib, x, y, brightness);
 		break;
 	}
 }
@@ -478,7 +488,7 @@ void ags_copyArea_shadow(int sx, int sy, int w, int h, int dx, int dy) {
 	if (!ags_check_param(&sx, &sy, &w, &h)) return;
 	if (!ags_check_param(&dx, &dy, &w, &h)) return;
 	
-	sdl_copyAreaSP16_shadow(sx, sy, w, h, dx, dy, 255);
+	gfx_copyAreaSP16_shadow(sx, sy, w, h, dx, dy, 255);
 }
 
 void ags_copyArea_transparent(int sx, int sy, int w, int h, int dx, int dy, int col) {
@@ -487,7 +497,7 @@ void ags_copyArea_transparent(int sx, int sy, int w, int h, int dx, int dy, int
 	if (!ags_check_param(&sx, &sy, &w, &h)) return;
 	if (!ags_check_param(&dx, &dy, &w, &h)) return;
 	
-	sdl_copyAreaSP(sx, sy, w, h, dx, dy, col);
+	gfx_copyAreaSP(sx, sy, w, h, dx, dy, col);
 }
 
 void ags_copyArea_alphaLevel(int sx, int sy, int w, int h, int dx, int dy, int lv) {
@@ -496,7 +506,7 @@ void ags_copyArea_alphaLevel(int sx, int sy, int w, int h, int dx, int dy, int l
 	if (!ags_check_param(&sx, &sy, &w, &h)) return;
 	if (!ags_check_param(&dx, &dy, &w, &h)) return;
 	
-	sdl_copyAreaSP16_alphaLevel(sx, sy, w, h, dx, dy, lv);
+	gfx_copyAreaSP16_alphaLevel(sx, sy, w, h, dx, dy, lv);
 }
 
 void ags_copyArea_alphaBlend(int sx, int sy, int w, int h, int dx, int dy, int lv) {
@@ -505,14 +515,14 @@ void ags_copyArea_alphaBlend(int sx, int sy, int w, int h, int dx, int dy, int l
 	if (!ags_check_param(&sx, &sy, &w, &h)) return;
 	if (!ags_check_param(&dx, &dy, &w, &h)) return;
 	
-	sdl_copyAreaSP16_alphaBlend(sx, sy, w, h, dx, dy, lv);
+	gfx_copyAreaSP16_alphaBlend(sx, sy, w, h, dx, dy, lv);
 }
 
-MyRectangle ags_floodFill(int x, int y, int col) {
+SDL_Rect ags_floodFill(int x, int y, int col) {
 	if (!ags_check_param_xy(&x, &y))
-		return (MyRectangle){};
+		return (SDL_Rect){};
 
-	return sdl_floodFill(x, y, col);
+	return gfx_floodFill(x, y, col);
 }
 
 void ags_copyFromAlpha(int sx, int sy, int w, int h, int dx, int dy, ALPHA_DIB_COPY_TYPE flg) {
@@ -521,7 +531,7 @@ void ags_copyFromAlpha(int sx, int sy, int w, int h, int dx, int dy, ALPHA_DIB_C
 	if (!ags_check_param(&sx, &sy, &w, &h)) return;
 	if (!ags_check_param(&dx, &dy, &w, &h)) return;
 	
-	sdl_copy_from_alpha(sx, sy, w, h, dx, dy, flg);
+	gfx_copy_from_alpha(sx, sy, w, h, dx, dy, flg);
 }
 
 void ags_copyToAlpha(int sx, int sy, int w, int h, int dx, int dy, ALPHA_DIB_COPY_TYPE flg) {
@@ -530,7 +540,7 @@ void ags_copyToAlpha(int sx, int sy, int w, int h, int dx, int dy, ALPHA_DIB_COP
 	if (!ags_check_param(&sx, &sy, &w, &h)) return;
 	if (!ags_check_param(&dx, &dy, &w, &h)) return;
 	
-	sdl_copy_to_alpha(sx, sy, w, h, dx, dy, flg);
+	gfx_copy_to_alpha(sx, sy, w, h, dx, dy, flg);
 }
 
 void ags_alpha_uppercut(int sx, int sy, int w, int h, int s, int d) {
@@ -592,10 +602,10 @@ void ags_alpha_setPixel(int x, int y, int w, int h, uint8_t *b) {
 
 void ags_runEffect(int duration_ms, bool cancelable, ags_EffectStepFunc step, void *arg) {
 	unsigned wflags = cancelable ? KEYWAIT_CANCELABLE : KEYWAIT_NONCANCELABLE;
-	int start = sdl_getTicks();
-	for (int t = 0; t < duration_ms; t = sdl_getTicks() - start) {
+	int start = sys_get_ticks();
+	for (int t = 0; t < duration_ms; t = sys_get_ticks() - start) {
 		step(arg, (float)t / duration_ms);
-		int key = sys_keywait(start + t + 16 - sdl_getTicks(), wflags);
+		int key = sys_keywait(start + t + 16 - sys_get_ticks(), wflags);
 		if (cancelable && key) {
 			nact->waitcancel_key = key;
 			break;
@@ -604,22 +614,22 @@ void ags_runEffect(int duration_ms, bool cancelable, ags_EffectStepFunc step, vo
 	step(arg, 1.0);
 }
 
-static void fade(int duration, bool cancelable, enum sdl_effect_type type) {
+static void fade(int duration, bool cancelable, enum effect_type type) {
 	nact->waitcancel_key = 0;
 
 	SDL_Rect rect = {0, 0, nact->ags.view_area.w, nact->ags.view_area.h};
-	struct sdl_effect *eff = sdl_effect_init(
+	struct effect *eff = effect_init(
 		&rect, NULL, 0, 0,
-		sdl_getDIB(), nact->ags.view_area.x, nact->ags.view_area.y,
+		gfx_getDIB(), nact->ags.view_area.x, nact->ags.view_area.y,
 		type);
-	ags_runEffect(duration, cancelable, (ags_EffectStepFunc)sdl_effect_step, eff);
-	sdl_effect_finish(eff);
+	ags_runEffect(duration, cancelable, (ags_EffectStepFunc)effect_step, eff);
+	effect_finish(eff);
 }
 
 void ags_fadeIn(int rate, bool flag) {
 	fade_outed = false;
 	if (nact->ags.world_depth == 8)
-		sdl_setPalette(nact->ags.pal, 0, 256);
+		gfx_setPalette(nact->ags.pal, 0, 256);
 
 	if (!need_update)
 		return;
@@ -627,7 +637,7 @@ void ags_fadeIn(int rate, bool flag) {
 	int duration = rate * 16 * 1000 / 60;
 	fade(duration, flag, nact->ags.world_depth == 8 ? EFFECT_FADEIN : EFFECT_DITHERING_FADEIN);
 
-	sdl_updateAll(&nact->ags.view_area);
+	gfx_updateAll(&nact->ags.view_area);
 }
 
 void ags_fadeOut(int rate, bool flag) {
@@ -642,14 +652,14 @@ void ags_fadeOut(int rate, bool flag) {
 		for (int i = 0; i < 256; i++) {
 			pal[i] = (SDL_Color){0, 0, 0, 255};
 		}
-		sdl_setPalette(pal, 0, 256);
+		gfx_setPalette(pal, 0, 256);
 	}
 }
 
 void ags_whiteIn(int rate, bool flag) {	
 	fade_outed = false;
 	if (nact->ags.world_depth == 8)
-		sdl_setPalette(nact->ags.pal, 0, 256);
+		gfx_setPalette(nact->ags.pal, 0, 256);
 
 	if (!need_update)
 		return;
@@ -657,7 +667,7 @@ void ags_whiteIn(int rate, bool flag) {
 	int duration = rate * 16 * 1000 / 60;
 	fade(duration, flag, nact->ags.world_depth == 8 ? EFFECT_WHITEIN : EFFECT_DITHERING_WHITEIN);
 
-	sdl_updateAll(&nact->ags.view_area);
+	gfx_updateAll(&nact->ags.view_area);
 }
 
 void ags_whiteOut(int rate, bool flag) {
@@ -670,7 +680,7 @@ void ags_whiteOut(int rate, bool flag) {
 	if (nact->ags.world_depth == 8) {
 		SDL_Color pal[256];
 		memset(&pal, 255, sizeof(pal));
-		sdl_setPalette(pal, 0, 256);
+		gfx_setPalette(pal, 0, 256);
 	}
 }
 
@@ -692,7 +702,7 @@ void ags_setTextDecorationColor(int col) {
 
 void ags_setCursorType(int type) {
 	if (nact->ags.noimagecursor && type >= 100) return;
-	sdl_setCursorType(type);
+	cursor_set_type(type);
 }
 
 void ags_loadCursor(int p1,int p2) {
@@ -715,26 +725,26 @@ void ags_setCursorLocation(int x, int y, bool is_dibgeo, bool for_selection) {
 		// We can't move the actual cursor in the browser, but can change the
 		// internal mouse coordinates. This can help with keyboard/gamepad
 		// navigation.
-		sdl_setCursorInternalLocation(x, y);
+		event_set_mouse_internal_location(x, y);
 		EM_ASM({ xsystem35.shell.showMouseMoveEffect($0, $1); }, x, y);
-		sdl_sleep(cursor_move_time);
+		sys_sleep(cursor_move_time);
 	}
 #else
 	if (nact->ags.mouse_warp_enabled) {
-		MyPoint p;
+		SDL_Point p;
 		sys_getMouseInfo(&p, is_dibgeo);
 		int dx = x - p.x;
 		int dy = y - p.y;
 		for (int i = 1; i < 8; i++) {
 			int xi = ((dx*i*i*i) >> 9) - ((3*dx*i*i)>> 6) + ((3*dx*i) >> 3) + p.x;
 			int yi = ((dy*i*i*i) >> 9) - ((3*dy*i*i)>> 6) + ((3*dy*i) >> 3) + p.y;
-			sdl_setCursorLocation(xi, yi);
-			sdl_sleep(cursor_move_time / 7);
+			event_set_mouse_location(xi, yi);
+			sys_sleep(cursor_move_time / 7);
 		}
-		sdl_setCursorLocation(x, y);
+		event_set_mouse_location(x, y);
 	} else if (!for_selection) {
-		sdl_setCursorInternalLocation(x, y);
-		sdl_sleep(cursor_move_time);
+		event_set_mouse_internal_location(x, y);
+		sys_sleep(cursor_move_time);
 	}
 #endif
 }
@@ -758,7 +768,7 @@ void ags_copyArea_shadow_withrate(int sx, int sy, int w, int h, int dx, int dy,
 	if (!ags_check_param(&sx, &sy, &w, &h)) return;
 	if (!ags_check_param(&dx, &dy, &w, &h)) return;
 	
-	sdl_copyAreaSP16_shadow(sx, sy, w, h, dx, dy, lv);
+	gfx_copyAreaSP16_shadow(sx, sy, w, h, dx, dy, lv);
 } 
 
 void ags_setCursorMoveTime(int msec) {
@@ -774,10 +784,14 @@ surface_t *ags_getDIB() {
 }
 
 void ags_autorepeat(bool enable) {
-	sdl_setAutoRepeat(enable);
+	if (enable) {
+		// SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);
+	} else {
+		// SDL_EnableKeyRepeat(0, 0);
+	}
 }
 
-bool ags_clipCopyRect(const MyRectangle *sw, const MyRectangle *dw, int *sx, int *sy, int *dx, int *dy, int *w, int *h) {
+bool ags_clipCopyRect(const SDL_Rect *sw, const SDL_Rect *dw, int *sx, int *sy, int *dx, int *dy, int *w, int *h) {
 	// Clip source rectangle to source window
 	SDL_Rect sr = {*sx, *sy, *w, *h};
 	if (!SDL_IntersectRect(&sr, sw, &sr))
