@@ -249,25 +249,25 @@ void exec_command(void) {
 		/* 小文字コマンド */
 		switch(sl_getc()) {
 		case 0x00:
-			commands2F00(); break;
+			commandTOC(); break;
 		case 0x01:
-			commands2F01(); break;
+			commandTOS(); break;
 		case 0x02:
-			commands2F02(); break;
+			commandTPC(); break;
 		case 0x03:
-			commands2F03(); break;
+			commandTPS(); break;
 		case 0x04:
-			commands2F04(); break;
+			commandTOP(); break;
 		case 0x05:
-			commands2F05(); break;
+			commandTPP(); break;
 		case 0x06:
 			commandsINC(); break;
 		case 0x07:
 			commandsDEC(); break;
 		case 0x08:
-			commands2F08(); break;
+			commandTAA(); break;
 		case 0x09:
-			commands2F09(); break;
+			commandTAB(); break;
 		case 0x0a:
 			commands2F0A(); break;
 		case 0x0b:
@@ -319,23 +319,23 @@ void exec_command(void) {
 		case 0x22:
 			commandHH(); break;
 		case 0x23:
-			commands2F23(); break;
+			commandLC(0); break;
 		case 0x24:
-			commands2F24(); break;
+			commandLE(0); break;
 		case 0x25:
-			commands2F25(); break;
+			commandLXG(0); break;
 		case 0x26:
-			commands2F26(); break;
+			commandMI(0); break;
 		case 0x27:
-			commands2F27(); break;
+			commandMS(0); break;
 		case 0x28:
-			commands2F28(); break;
+			commandMT(0); break;
 		case 0x29:
-			commands2F29(); break;
+			commandNT(0); break;
 		case 0x2a:
-			commands2F2A(); break;
+			commandQE(0); break;
 		case 0x2b:
-			commands2F2B(); break;
+			commandUP(); break;
 		case 0x2c:
 			commandF(); break;
  		case 0x2d:
@@ -385,7 +385,7 @@ void exec_command(void) {
 		case 0x43:
 			commands2F43(); break;
 		case 0x44:
-			commands2F44(); break;
+			commandMHH(); break;
 		case 0x45:
 			commands2F45(); break;
 		case 0x46:
@@ -403,15 +403,15 @@ void exec_command(void) {
 		case 0x4c:
 			commands2F4C(); break;
 		case 0x4d:
-			commands2F4D(); break;
+			commandLXWT(); break;
 		case 0x4e:
-			commands2F4E(); break;
+			commandLXWS(); break;
 		case 0x4f:
-			commands2F4F(); break;
+			commandLXWE(); break;
 		case 0x50:
-			commands2F50(); break;
+			commandLXWH(); break;
 		case 0x51:
-			commands2F51(); break;
+			commandLXWHH(); break;
 		case 0x52:
 			commands2F52(); break;
 		case 0x53:
@@ -421,7 +421,7 @@ void exec_command(void) {
 		case 0x55:
 			commands2F55(); break;
 		case 0x56:
-			commands2F56(); break;
+			commandLXF(); break;
 		case 0x57:
 			commands2F57(); break;
 		case 0x58:
@@ -731,7 +731,7 @@ void exec_command(void) {
 	case 'L':
 		switch(sl_getc()) {
 		case 'C':
-			commandLC(); break;
+			commandLC(':'); break;
 		case 'D':
 			commandLD(); break;
 		case 'P':
@@ -739,7 +739,7 @@ void exec_command(void) {
 		case 'T':
 			commandLT(); break;
 		case 'E':
-			commandLE(); break;
+			commandLE(':'); break;
 		case 'L':
 			commandLL(); break;
 		case 'H':
@@ -761,7 +761,7 @@ void exec_command(void) {
 		case 'X':
 			switch(sl_getc()) {
 			case 'G':
-				commandLXG(); break;
+				commandLXG(':'); break;
 			case 'O':
 				commandLXO(); break;
 			case 'C':
@@ -803,7 +803,7 @@ void exec_command(void) {
 		case 'H':
 			commandMH(); break;
 		case 'I':
-			commandMI(); break;
+			commandMI(':'); break;
 		case 'J':
 			commandMJ(); break;
 		case 'L':
@@ -815,9 +815,9 @@ void exec_command(void) {
 		case 'P':
 			commandMP(); break;
 		case 'S':
-			commandMS(); break;
+			commandMS(':'); break;
 		case 'T':
-			commandMT(); break;
+			commandMT(':'); break;
 		case 'V':
 			commandMV(); break;
 		case 'Z':
@@ -871,7 +871,7 @@ void exec_command(void) {
 		case 'O':
 			commandNO(); break;
 		case 'T':
-			commandNT(); break;
+			commandNT(':'); break;
 		case 'D':
 			switch(sl_getc()) {
 			case 'C':
@@ -943,7 +943,7 @@ void exec_command(void) {
 		case 'D':
 			commandQD(); break;
 		case 'E':
-			commandQE(); break;
+			commandQE(':'); break;
 		case 'P':
 			commandQP(); break;
 		default:
