@@ -36,6 +36,7 @@
 #include "savedata.h"
 #include "utfsjis.h"
 #include "cg.h"
+#include "cmd_check.h"
 
 void commandLD() {
 	/* 変数領域などのデータをロードする。（全ロード）*/
@@ -106,24 +107,38 @@ void commandLT() {
 	TRACE("LT %d,%p",num, var);
 }
 
-void commandLE() {
+void commandLE(char terminator) {
 	int type = sl_getc();
-	const char *filename = sl_getString(':');
+	const char *filename = sl_getString(terminator);
+	char *fname_utf8 = toUTF8(filename);
+	char *fallback_fname = NULL;
+	if (strchr(fname_utf8, '\\')) {
+		fallback_fname = strdup(fname_utf8);
+		for (char *p = fname_utf8; *p; p++) {
+			if (*p == '\\')
+				*p = '/';
+		}
+	}
+
 	int var, cnt;
 	struct VarRef vref;
-
-	char *fname_utf8 = toUTF8(filename);
 	switch (type) {
 	case 0:
 		getCaliArray(&vref);
 		var = vref.var;
 		cnt = getCaliValue();
 		sysVar[0] = load_vars_from_file(fname_utf8, &vref, cnt);
+		// For compatibility; the QE command in v2.16.1 and earlier did not
+		// convert backslashes to slashes.
+		if (sysVar[0] == SAVE_LOADERR && fallback_fname)
+			sysVar[0] = load_vars_from_file(fallback_fname, &vref, cnt);
 		break;
 	case 1:
 		var = getCaliValue();
 		cnt = getCaliValue();
 		sysVar[0] = load_strs_from_file(fname_utf8, var, cnt);
+		if (sysVar[0] == SAVE_LOADERR && fallback_fname)
+			sysVar[0] = load_strs_from_file(fallback_fname, var, cnt);
 		break;
 	default:
 		var = getCaliValue();
@@ -131,6 +146,8 @@ void commandLE() {
 		WARNING("Unknown LE command %d", type);
 		break;
 	}
+	if (fallback_fname)
+		free(fallback_fname);
 	free(fname_utf8);
 	
 	TRACE("LE %d,%s,%d,%d:",type, filename, var, cnt);
@@ -254,11 +271,11 @@ void commandLHW() {
 	TRACE("LHW %d,%d:",p1,no);
 }
 
-void commandLC() {
+void commandLC(char terminator) {
 	int x = getCaliValue();
 	int y = getCaliValue();
-	const char *filename = sl_getString(':');
-	
+	const char *filename = sl_getString(terminator);
+
 	char *fname_utf8 = toUTF8(filename);
 	sysVar[0] = cg_load_with_filename(fname_utf8, x, y);
 	free(fname_utf8);
@@ -266,11 +283,11 @@ void commandLC() {
 	TRACE("LC %d,%d,%s:", x, y, filename);
 }
 
-void commandLXG() {
+void commandLXG(char terminator) {
 	/* ファイルを選択する */
 	int file_name = getCaliValue();
-	const char *title = sl_getString(':');
-	const char *filter = sl_getString(':');
+	const char *title = sl_getString(terminator);
+	const char *filter = sl_getString(terminator);
 
 	TRACE_UNIMPLEMENTED("LXG %d,%s,%s:", file_name, title, filter);
 }
@@ -376,3 +393,48 @@ void commandLXX() {
 
 	TRACE("LXX %d,%d,%d:", type, num, *var);
 }
+
+void commandLXWT() {
+	int eNum = getCaliValue();
+	const char *sText = sl_getString(0);
+
+	TRACE_UNIMPLEMENTED("LXWT %d, %s:", eNum, sText);
+}
+
+void commandLXWS() {
+	int eNum = getCaliValue();
+	int eTextNum = getCaliValue();
+
+	TRACE_UNIMPLEMENTED("LXWS %d, %d:", eNum, eTextNum);
+}
+
+void commandLXWE() {
+	int eNum = getCaliValue();
+	int eType = getCaliValue();
+
+	TRACE_UNIMPLEMENTED("LXWE %d, %d:", eNum, eType);
+}
+
+void commandLXWH() {
+	int eFile = getCaliValue();
+	int nFlg = sl_getc();
+	int eNum = getCaliValue();
+
+	TRACE_UNIMPLEMENTED("LXWH %d, %d, %d:", eFile, nFlg, eNum);
+}
+
+void commandLXWHH() {
+	int eFile = getCaliValue();
+	int nFlg  = sl_getc();
+	int eNum  = getCaliValue();
+
+	TRACE_UNIMPLEMENTED("LXWHH %d, %d, %d:", eFile, nFlg, eNum);
+}
+
+void commandLXF() {
+	int file_name = getCaliValue();
+	const char *title = sl_getString(0);
+	const char *folder = sl_getString(0);
+
+	TRACE_UNIMPLEMENTED("LXF %d, %s, %s:", file_name, title, folder);
+}
