@@ -34,15 +34,16 @@
 #include "message.h"
 #include "hankaku.h"
 #include "hacks.h"
+#include "cmd_check.h"
 
 /* MI 用パラメータ */
-INPUTSTRING_PARAM mi_param;
+static INPUTSTRING_PARAM mi_param;
 
-void commandMS() {
+void commandMS(char terminator) {
 	/* Xコマンドで表示される文字列領域に文字列を入れる */
 	int num = getCaliValue();
-	const char *str = sl_getString(':');
-	
+	const char *str = sl_getString(terminator);
+
 	svar_set(num, str);
 	TRACE("MS %d,%s:",num,str);
 }
@@ -90,11 +91,11 @@ void commandMP() {
 	free(str);
 }
 
-void commandMI() { /* T2 */
+void commandMI(char terminator) {
 	/* ユーザーによる文字列の入力 */
 	int dst_no  = getCaliValue();
 	int max_len = getCaliValue();
-	const char *title = sl_getString(':');
+	const char *title = sl_getString(terminator);
 	char *t1, *t2, *t3;
 	
 	t1 = toUTF8(title);
@@ -147,9 +148,9 @@ void commandMC() {
 	TRACE("MC %d,%d:",num1,num2);
 }
 
-void commandMT() {
+void commandMT(char terminator) {
 	/* ウインドウのタイトル文字列を設定する */
-	const char *str = sl_getString(':');
+	const char *str = sl_getString(terminator);
 	
 	if (nact->game_title_utf8)
 		free(nact->game_title_utf8);
@@ -186,6 +187,17 @@ void commandMH() {
 	TRACE("MH %d,%d,%d:",num1,fig,num2);
 }
 
+void commandMHH() {
+	int num1 = getCaliValue();
+	int fig  = getCaliValue();
+	int num2 = getCaliValue();
+	char buf[256];
+
+	svar_set(num1, format_number(num2, fig, buf));
+
+	TRACE("MHH %d, %d, %d:", num1, fig, num2);
+}
+
 void commandMV() {
 	/* シナリオバージョンをシステムへ通知する */
 	int version = getCaliValue();
