@@ -30,9 +30,10 @@
 #include "xsystem35.h"
 #include "scenario.h"
 #include "menu.h"
+#include "cmd_check.h"
 
 /* NI/NT 用パラメータ */
-INPUTNUM_PARAM ni_param;
+static INPUTNUM_PARAM ni_param;
 
 void commandNB() {
 	/* var1 から始まるcount個の変数へ
@@ -376,9 +377,9 @@ void commandNI() { /* From Panyo */
 	TRACE("NI %p,%d,%d,%d:", var, def, _min, _max);
 }
 
-void commandNT() { /* From Panyo */
+void commandNT(char terminator) {
 	/* NIコマンドで表示するタイトルを設定する。*/
-	const char *str = sl_getString(':');
+	const char *str = sl_getString(terminator);
 
 	free(ni_param.title);
 	ni_param.title = toUTF8(str);
