@@ -31,7 +31,6 @@
 #include "input.h"
 #include "scenario.h"
 #include "cmd_check.h"
-#include "sdl_core.h"
 #include "scheduler.h"
 #include "music_cdrom.h"
 #include "hacks.h"
@@ -68,14 +67,14 @@ unsigned Y3waitFlags = KEYWAIT_CANCELABLE;
  * delay, when a button is pressed.
  *
  * For Rance4 v2, this does not work because the UI loop also checks keyboard
- * status, so we use a different hack. See rance4v2_hack() in sdl_event.c.
+ * status, so we use a different hack. See rance4v2_hack() in event.c.
  */
 static void rance4_Y3_IM_hack() {
 	static int count;
 
 	int button_pressed = sys_getInputInfo();
 	if (!button_pressed) {
-		sdl_wait_vsync();
+		sys_wait_vsync();
 		count = 0;
 	}
 	commandIM();
