@@ -27,7 +27,7 @@
 
 #include "portab.h"
 #include "xsystem35.h"
-#include "sdl_core.h"
+#include "gfx.h"
 #include "scheduler.h"
 #include "ags.h"
 #include "scenario.h"
@@ -44,13 +44,13 @@ static struct {
 } counters[257];  // [0] for ZT 1-5, [1..256] for ZT 10-11
 
 static void reset_counter(int num, int divisor, int offset) {
-	counters[num].base = sdl_getTicks() - offset;
+	counters[num].base = sys_get_ticks() - offset;
 	counters[num].divisor = divisor;
 }
 
 static uint32_t get_counter(int num) {
 	scheduler_on_event(SCHEDULER_EVENT_TIMER_CHECK);
-	return sdl_getTicks() - counters[num].base;
+	return sys_get_ticks() - counters[num].base;
 }
 
 void commandZC() {
@@ -126,6 +126,10 @@ void commandZW() {
 	int sw = getCaliValue();
 	
 	if (sw < 256) {
+		// System 3.5 has a bug in which ZW 1 does not disable message waiting,
+		// and Rance 2 depends on it.
+		if (game_id == GAME_RANCE2)
+			sw = 2;
 		nact->messagewait_enable = ((sw & 0xff) > 1);
 		nact->messagewait_cancelled = false;
 	} else {
@@ -458,7 +462,7 @@ void commandZZ10() {
 	/* スクリーンモードを取得する */
 	int *var = getCaliVariable();
 
-	*var = sdl_isFullscreen() ? 1 : 0;
+	*var = gfx_isFullscreen() ? 1 : 0;
 	
 	TRACE("ZZ10 %d:",*var);
 }
