@@ -27,7 +27,7 @@
 #include <math.h>
 
 #include "portab.h"
-#include "sdl_core.h"
+#include "gfx.h"
 #include "input.h"
 #include "ags.h"
 #include "system.h"
@@ -39,19 +39,19 @@ static bool ecp_cancel;
 #define EC_WAIT \
 	if ((key |= sys_getInputInfo()) && ecp_cancel) break; \
 	do {												  \
-		int wait_ms = cnt - sdl_getTicks();				  \
+		int wait_ms = cnt - sys_get_ticks();				  \
 		if (wait_ms >= 16)								  \
 			key = sys_keywait(wait_ms, ecp_cancel ? KEYWAIT_CANCELABLE : KEYWAIT_NONCANCELABLE); \
 	} while (0)
 
 
 static void eCopyUpdateArea(int sx, int sy, int w, int h, int dx, int dy) {
-	MyRectangle src = {sx, sy, w, h};
-	MyPoint dst = {
+	SDL_Rect src = {sx, sy, w, h};
+	SDL_Point dst = {
 		dx - nact->ags.view_area.x,
 		dy - nact->ags.view_area.y
 	};
-	sdl_updateArea(&src, &dst);
+	gfx_updateArea(&src, &dst);
 }
 
 static int eCopyArea5(int sx, int sy, int w, int h, int dx, int dy, int opt) {
@@ -60,7 +60,7 @@ static int eCopyArea5(int sx, int sy, int w, int h, int dx, int dy, int opt) {
 	static int hx[16]={ 0,32,16,48, 0,32,16,48,16,48, 0,32,16,48, 0,32};
 	static int hy[16]={ 0, 0,16,16,32,32,48,48, 0, 0,16,16,32,32,48,48};
 	
-	cnt = sdl_getTicks();
+	cnt = sys_get_ticks();
 	for (i = 0; i < 16; i++) {
 		cnt += waitcnt;
 		for (y = 0; y < (h -63); y += 64) {
@@ -81,7 +81,7 @@ static int eCopyArea6(int dx, int dy, int w, int h, int opt) {
 	int i, x, y, key = 0, cnt;
 	int waitcnt = opt == 0 ? 30 : opt;
 
-	cnt = sdl_getTicks();
+	cnt = sys_get_ticks();
 	for (i = 0; i < 7; i++) {
 		cnt += waitcnt;
 		for (x = 0; x < (w -63); x += 64) {
@@ -105,18 +105,18 @@ static int eCopyArea9(int sx, int sy, int w, int h, int dx, int dy, int opt) {
 	static int hintY[4] = {0,8,8,0};
 
 	
-	cnt = sdl_getTicks();
+	cnt = sys_get_ticks();
 	for (i = 0; i < 4; i++) {
 		cnt+=waitcnt;
 		for (y = 0; y < h -15; y+=16) {
 			for (x = 0; x < (w -7); x+=16) {
-				sdl_copyArea(sx + x + hintX[i],sy + y + hintY[i], 8, 8, dx + x + hintX[i], dy + y + hintY[i]);
+				gfx_copyArea(sx + x + hintX[i],sy + y + hintY[i], 8, 8, dx + x + hintX[i], dy + y + hintY[i]);
 			}
 		}
 		ags_updateArea(dx, dy, w, h);
 		EC_WAIT;
 	}
-	sdl_copyArea(sx, sy, w, h, dx, dy);
+	gfx_copyArea(sx, sy, w, h, dx, dy);
 	ags_updateArea(dx, dy, w, h);
 	return key;
 }
@@ -125,7 +125,7 @@ static int eCopyArea16(int dx, int dy, int w, int h, int opt) {
 	int i, x, key = 0, cnt;
 	int waitcnt = opt == 0 ? 30 : opt;
 	
-	cnt = sdl_getTicks();
+	cnt = sys_get_ticks();
 	for (i = 0; i < 8; i++) {
 		cnt += waitcnt;
 		for (x = 0; x < (w -15); x += 16) {
@@ -143,7 +143,7 @@ static int eCopyArea17(int dx, int dy, int w, int h, int opt) {
 	int waitcnt = opt == 0 ? 30 : opt;
 
 #define E17X 18
-	cnt = sdl_getTicks();
+	cnt = sys_get_ticks();
 	for (i = 0; i < E17X; i++) {
 		cnt += waitcnt;
 		for (y = 0; y < (h - E17X + 1); y += E17X) {
@@ -159,7 +159,7 @@ static int eCopyArea22(int sx, int sy, int w, int h, int dx, int dy, int opt) {
 	int i, x, y, key = 0, cnt;
 	int waitcnt = opt == 0 ? 80 : opt;
 	
-	cnt = sdl_getTicks();
+	cnt = sys_get_ticks();
 	for (i = 0; i < 2; i++) {
 		cnt += waitcnt;
 		for (y = 0; y < (h -3); y+=4) {
@@ -184,12 +184,12 @@ static int eCopyArea23(int sx, int sy, int w, int h, int dx, int dy, int opt) {
 	static int hintX[4] = {0,2,2,0};
 	static int hintY[4] = {0,2,0,2};
 	
-	cnt = sdl_getTicks();
+	cnt = sys_get_ticks();
 	for (i = 0; i < 4; i++) {
 		cnt += waitcnt;
 		for (y = 0; y < (h -3); y+=4) {
 			for (x = 0; x < (w -3); x+=4) {
-				sdl_copyArea(sx + x + hintX[i], sy + y + hintY[i], 2, 2,
+				gfx_copyArea(sx + x + hintX[i], sy + y + hintY[i], 2, 2,
 					 dx + x + hintX[i], dy + y + hintY[i]);
 			}
 		}
@@ -207,7 +207,7 @@ static int eCopyArea1000(int sx, int sy, int w, int h, int dx, int dy, int opt)
 }
 
 static int eCopyArea2000(int sx, int sy, int w, int h, int dx, int dy, int opt) {
-	sdl_fillRectangleRGB(dx, dy, w, h, 0, 0, 0);
+	gfx_fillRectangleRGB(dx, dy, w, h, 0, 0, 0);
 	ags_copyArea_alphaLevel(sx, sy, w, h, dx, dy, opt);
 	ags_updateArea(dx, dy, w, h);
 	return sys_getInputInfo();
@@ -315,9 +315,9 @@ void ags_eCopyArea(int sx, int sy, int w, int h, int dx, int dy, int sw, int opt
 
 	if (sw == NACT_EFFECT_MAGNIFY) {
 		SDL_Rect target_rect = { sx, sy, w, h };
-		struct sdl_effect *eff = sdl_effect_magnify_init(sdl_getDIB(), &nact->ags.view_area, &target_rect);
-		ags_runEffect(duration(sw, opt, NULL), cancel, (ags_EffectStepFunc)sdl_effect_step, eff);
-		sdl_effect_finish(eff);
+		struct effect *eff = effect_magnify_init(gfx_getDIB(), &nact->ags.view_area, &target_rect);
+		ags_runEffect(duration(sw, opt, NULL), cancel, (ags_EffectStepFunc)effect_step, eff);
+		effect_finish(eff);
 		// Actual copy.
 		ags_scaledCopyArea(
 			sx, sy, w, h,
@@ -326,24 +326,24 @@ void ags_eCopyArea(int sx, int sy, int w, int h, int dx, int dy, int sw, int opt
 		return;
 	}
 
-	enum sdl_effect_type sdl_effect = from_nact_effect(sw);
-	if (sdl_effect != EFFECT_INVALID) {
+	enum effect_type effect = from_nact_effect(sw);
+	if (effect != EFFECT_INVALID) {
 		SDL_Rect rect = { dx - nact->ags.view_area.x, dy - nact->ags.view_area.y, w, h };
-		// Note that we specify NULL (which means sdl_texture) for the old
-		// surface rather than sdl_getDIB(). This is to use the current display
+		// Note that we specify NULL (which means gfx_texture) for the old
+		// surface rather than gfx_getDIB(). This is to use the current display
 		// contents, not reflecting uncommitted palette changes.
-		struct sdl_effect *eff = sdl_effect_init(&rect, NULL, rect.x, rect.y, sdl_getDIB(), sx, sy, sdl_effect);
-		ags_runEffect(duration(sw, opt, &rect), cancel, (ags_EffectStepFunc)sdl_effect_step, eff);
-		sdl_effect_finish(eff);
+		struct effect *eff = effect_init(&rect, NULL, rect.x, rect.y, gfx_getDIB(), sx, sy, effect);
+		ags_runEffect(duration(sw, opt, &rect), cancel, (ags_EffectStepFunc)effect_step, eff);
+		effect_finish(eff);
 
 		// Actual copy.
 		switch (sw) {
 		case NACT_EFFECT_FADEOUT:
-			sdl_fillRectangleRGB(dx, dy, w, h, 0, 0, 0);
+			gfx_fillRectangleRGB(dx, dy, w, h, 0, 0, 0);
 			ags_updateArea(dx, dy, w, h);
 			break;
 		case NACT_EFFECT_WHITEOUT:
-			sdl_fillRectangleRGB(dx, dy, w, h, 255, 255, 255);
+			gfx_fillRectangleRGB(dx, dy, w, h, 255, 255, 255);
 			ags_updateArea(dx, dy, w, h);
 			break;
 		default:
@@ -363,7 +363,7 @@ void ags_eCopyArea(int sx, int sy, int w, int h, int dx, int dy, int sw, int opt
 	case 54:
 		ags_copyArea(sx, sy, w, h, dx, dy);
 		{
-			MyRectangle r = {dx, dy, w, h}, update;
+			SDL_Rect r = {dx, dy, w, h}, update;
 			SDL_IntersectRect(&nact->ags.view_area, &r, &update);
 			w = update.w;
 			h = update.h;
@@ -431,15 +431,15 @@ void ags_eSpriteCopyArea(int sx, int sy, int w, int h, int dx, int dy, int sw, i
 		return;
 	}
 
-	enum sdl_effect_type type = from_nact_sprite_effect(sw);
+	enum effect_type type = from_nact_sprite_effect(sw);
 	if (type == EFFECT_INVALID) {
 		WARNING("Invalid effect: %d", sw);
 		return;
 	}
 	SDL_Rect rect = { dx - nact->ags.view_area.x, dy - nact->ags.view_area.y, w, h };
-	struct sdl_effect *eff = sdl_sprite_effect_init(&rect, dx, dy, sx, sy, spCol, type);
-	ags_runEffect(duration(sw, opt, &rect), cancel, (ags_EffectStepFunc)sdl_effect_step, eff);
-	sdl_effect_finish(eff);
+	struct effect *eff = sprite_effect_init(&rect, dx, dy, sx, sy, spCol, type);
+	ags_runEffect(duration(sw, opt, &rect), cancel, (ags_EffectStepFunc)effect_step, eff);
+	effect_finish(eff);
 	// Actual copy.
 	if (sw == 5) {
 		ags_copyArea_shadow(sx, sy, w, h, dx, dy);
