@@ -25,7 +25,7 @@
 #include <limits.h>
 #include "config.h"
 #include "input.h"
-#include "sdl_core.h"
+#include "event.h"
 #include "scheduler.h"
 #include "xsystem35.h"
 #include "message.h"
@@ -51,9 +51,9 @@ void set_hak_keymode(int key, int mode) {
 	}
 }
 
-int sys_getMouseInfo(MyPoint *p, bool is_dibgeo) {
-	MyPoint _p;
-	int key = sdl_getMouseInfo(&_p);
+int sys_getMouseInfo(SDL_Point *p, bool is_dibgeo) {
+	SDL_Point _p;
+	int key = event_get_mouse(&_p);
 	
 	if (p) {
 		p->x = _p.x;
@@ -67,23 +67,23 @@ int sys_getMouseInfo(MyPoint *p, bool is_dibgeo) {
 }
 
 void sys_getWheelInfo(int *forward, int *back) {
-	sdl_getWheelInfo(forward, back);
+	event_get_wheel(forward, back);
 }
 
 void sys_clearWheelInfo(void) {
-	sdl_clearWheelInfo();
+	event_clear_wheel();
 }
 
 int sys_getKeyInfo() {
-	return sdl_getKeyInfo();
+	return event_get_key();
 }
 
 int sys_getJoyInfo() {
-	return sdl_getJoyInfo();
+	return event_get_joy();
 }
 
 int sys_getInputInfo() {
-	return sdl_getMouseInfo(NULL) | sdl_getKeyInfo() | sdl_getJoyInfo();
+	return event_get_mouse(NULL) | event_get_key() | event_get_joy();
 }
 
 int sys_keywait(int msec, unsigned flags) {
@@ -100,14 +100,14 @@ int sys_keywait(int msec, unsigned flags) {
 	}
 
 	int key=0, n;
-	int end = msec == INT_MAX ? INT_MAX : sdl_getTicks() + msec;
+	int end = msec == INT_MAX ? INT_MAX : sys_get_ticks() + msec;
 	while (!nact->is_quit &&
 		   !((flags & KEYWAIT_SKIPPABLE) && msgskip_isSkipping()) &&
-		   (n = end - sdl_getTicks()) > 0) {
+		   (n = end - sys_get_ticks()) > 0) {
 		if (n <= 16)
-			sdl_sleep(n);
+			sys_sleep(n);
 		else
-			sdl_wait_vsync();
+			sys_wait_vsync();
 		nact->callback();
 		key = sys_getInputInfo();
 		cancel_yield();  // We just yielded!
@@ -122,7 +122,7 @@ void sys_hit_any_key() {
 	if (msgskip_isSkipping()) {
 		if (msgskip_getFlags() & MSGSKIP_STOP_ON_CLICK && sys_getInputInfo())
 			msgskip_activate(false);
-		sdl_sleep(30);
+		sys_sleep(30);
 		return;
 	}
 
