@@ -18,38 +18,39 @@
 */
 
 #include <stdlib.h>
-#include <SDL_cpuinfo.h>
-
-#if defined(__ARM_NEON)
-#define STBI_NEON
-#endif
-#define STBI_NO_STDIO
-#define STBI_ONLY_JPEG
-#define STB_IMAGE_IMPLEMENTATION
-#include "stb_image.h"
 
 #include "config.h"
 
 #include "system.h"
 #include "jpeg.h"
 
+// Disable the bicubic chroma filter to avoid color bleeding in Graymerca.
+#define NJ_CHROMA_FILTER 0
+#include "nanojpeg.c"
+
 bool jpeg_checkfmt(uint8_t *data) {
 	return data[0] == 0xff && data[1] == 0xd8;
 }
 
 cgdata *jpeg_extract(uint8_t *data, size_t size) {
-	int width, height, channels;
-	uint8_t *pixels = stbi_load_from_memory(data, size, &width, &height, &channels, 3);
-	if (!pixels) {
-		WARNING("cannot decode jpeg: %s", stbi_failure_reason());
+	njInit();
+	nj_result_t err = njDecode(data, size);
+	if (err != NJ_OK) {
+		WARNING("cannot decode jpeg: %d", err);
+		return NULL;
+	}
+	if (!njIsColor()) {
+		WARNING("grayscale jpeg is not supported:");
+		njDone();
 		return NULL;
 	}
-
 	cgdata *cg = calloc(1, sizeof(cgdata));
 	cg->type = ALCG_JPEG;
-	cg->width  = width;
-	cg->height = height;
+	cg->width  = njGetWidth();
+	cg->height = njGetHeight();
 	cg->depth  = 24;
-	cg->pic = pixels;
+	cg->pic = nj.rgb;  // steal the buffer from nj_context_t
+	nj.rgb = NULL;
+	njDone();
 	return cg;
 }
