@@ -29,7 +29,6 @@
 
 #include "portab.h"
 #include "windowframe.h"
-#include "sdl_core.h"
 #include "xsystem35.h"
 #include "message.h"
 #include "variable.h"
@@ -49,7 +48,7 @@
 static int frameType;
 static int frameDot;
 /* 現在の文字表示位置 */
-static MyPoint msgcur;
+static SDL_Point msgcur;
 static bool nextLineIsAfterKaigyou = false;
 
 /* Private Methods */
@@ -126,21 +125,21 @@ void msg_putMessage(const char *m) {
 	
 	ags_setFontWithWeight(nact->ags.font_type, msg.MsgFontSize, nact->ags.font_weight);
 
-	MyRectangle drawn;
+	SDL_Rect drawn;
 	msgcur.x += ags_drawString(msgcur.x, msgcur.y, m, msg.MsgFontColor, &drawn);
 
-	if (nact->messagewait_enable && !nact->messagewait_cancelled && !msgskip_isSkipping()) {
+	if (nact->messagewait_enable && nact->messagewait_time > 0 &&
+		!nact->messagewait_cancelled && !msgskip_isSkipping()) {
 		int x;
 		for (x = 0; x < drawn.w; x+=16) {
 			ags_updateArea(drawn.x + x, drawn.y, 16, drawn.h);
-			if (nact->messagewait_cancel) {
-				if (sys_getInputInfo()) {
-					nact->messagewait_cancelled = true;
-					ags_updateArea(drawn.x, drawn.y, drawn.w, drawn.h);
-					break;
-				}
-				sdl_sleep(nact->messagewait_time * 10);
+			int key = sys_getInputInfo();
+			if (nact->messagewait_cancel && key) {
+				nact->messagewait_cancelled = true;
+				ags_updateArea(drawn.x, drawn.y, drawn.w, drawn.h);
+				break;
 			}
+			sys_sleep(nact->messagewait_time * 10);
 			nact->callback();
 		}
 	} else {
@@ -265,7 +264,7 @@ void msg_setMessageLocation(int x, int y) {
 	nextLineIsAfterKaigyou = false;
 }
 
-void msg_getMessageLocation(MyPoint *loc) {
+void msg_getMessageLocation(SDL_Point *loc) {
 	loc->x = msgcur.x;
 	loc->y = msgcur.y;
 }
@@ -276,7 +275,7 @@ void msg_hitAnyKey() {
 		[UTF8] = "▼",
 	};
 	
-	MyRectangle r;
+	SDL_Rect r;
 	int x = msg.win->x + msg.win->width - msg.MsgFontSize;
 	int y = msg.win->y + msg.win->height - msg.MsgFontSize;
 	ags_drawString(x, y, prompt[nact->encoding], msg.HitAnyKeyMsgColor, &r);
