@@ -31,7 +31,7 @@
 #include "portab.h"
 #include "scenario.h"
 #include "xsystem35.h"
-#include "sdl_core.h"
+#include "gfx.h"
 #include "scheduler.h"
 #include "ags.h"
 #include "nact.h"
@@ -112,7 +112,7 @@ void nact_main() {
 		nact->current_page = sl_getPage();
 		nact->current_addr = sl_getIndex();
 		if (dbg_trapped()) {
-			sdl_updateScreen();
+			gfx_updateScreen();
 			dbg_main(0);
 		}
 
